################################################################################
## Script for producing figures in Bilbao et al. (2025) The sensitivity of 
## EC-Earth3 decadal predictions to the choice of volcanic forcing dataset: 
## Insights for the next major eruption.
## Script purpose: Figures 1-3
## Date: 03/2025
## Author: Roberto Bilbao (roberto.bilbao@bsc.es)
################################################################################

# Load libraries
library(maps)
library(RColorBrewer)
library(s2dv)
library(ncdf4)
library("viridis")

# Path to data
pathdat = ''

#CMIP6 Forcing
t = 1333
tn = 516
nc_data <- nc_open(paste0(pathdat,'CMIP6_1850_2014_EC_EARTH_aerosol_radiation_2D_3.0.0_L91.nc'))
cmip6 <- Reorder(ncvar_get(nc_data, "AOD_sun", start=c(1,1,1,t), count=c(-1,-1,-1,tn)),c(4,3,2,1))
lat_cmip6 = ncvar_get(nc_data, "latitude")
alt_cmip6 = ncvar_get(nc_data, "altitude")
nc_close(nc_data) 
names(dim(cmip6)) = c("time","lev","lat","wl")
dim(cmip6)
dim(alt_cmip6)

#EVA
t = 1
tn = -1
nc_data <- nc_open(paste0(pathdat,'EVA_CONFESS_EC_EARTH_aerosol_radiation_2D_L91.nc'))
eva <- Reorder(ncvar_get(nc_data, "AOD_sun", start=c(1,1,1,t), count=c(-1,-1,-1,tn)),c(4,3,2,1))
lat_eva = ncvar_get(nc_data, "latitude")
alt_eva = ncvar_get(nc_data, "altitude")
nc_close(nc_data) 
names(dim(eva)) = c("time","lev","lat","wl")
dim(eva)
dim(alt_eva)

#EVA_H
t = 1
tn = -1
nc_data <- nc_open(paste0(pathdat,'EVA_H_AgungElChichonPina_notop.nc'))
evah <- Reorder(ncvar_get(nc_data, "AOD_sun", start=c(1,1,1,t), count=c(-1,-1,-1,tn)),c(4,3,2,1))
lat_evah = ncvar_get(nc_data, "latitude")
alt_evah = ncvar_get(nc_data, "altitude")
nc_close(nc_data)
names(dim(evah)) = c("time","lev","lat","wl")
dim(evah)
dim(alt_evah)

#EVA_H Carn16
t = 1
tn = -1
nc_data <- nc_open(paste0(pathdat,'EVA_H_Carn16_notop.nc'))
evah_carn <- Reorder(ncvar_get(nc_data, "AOD_sun", start=c(1,1,1,t), count=c(-1,-1,-1,tn)),c(4,3,2,1))
nc_close(nc_data) 
names(dim(evah_carn)) = c("time","lev","lat","wl")
dim(evah_carn)

# Total AOD EVAH
taod_evah = apply(evah, c(1,3,4), sum)
dim(taod_evah)
w = cos(lat_evah * (pi/180))
dim(w)
gmaod_evah = apply(taod_evah, c(1,3), weighted.mean, w)
dim(gmaod_evah)

# Total AOD EVAH Carn16
taod_evah_carn = apply(evah_carn, c(1,3,4), sum)
dim(taod_evah_carn)
w = cos(lat_evah * (pi/180))
dim(w)
gmaod_evah_carn = apply(taod_evah_carn, c(1,3), weighted.mean, w)
dim(gmaod_evah_carn)

# Total AOD EVA
taod_eva = apply(eva, c(1,3,4), sum)
w = cos(lat_eva * (pi/180))
dim(w)
gmaod_eva = apply(taod_eva, c(1,3), weighted.mean, w)
dim(gmaod_eva)

# Total AOD CMIP6
cmip6[evah == 0] = 0
taod_cmip6 = apply(cmip6, c(1,3,4), sum)
w2 = cos(lat_cmip6 * (pi/180))
dim(w2)
gmaod_cmip6 = apply(taod_cmip6, c(1,3), weighted.mean, w2)
dim(gmaod_cmip6)

# Figure 1 ############################################################
options(repr.plot.width = 10, repr.plot.height = 8, repr.plot.res = 200)

par(mfrow=c(2,1))

pcexlab=1.2
pcexmain=1.2
pcexax=1.2

wv = 11
yrs = c(1:516)
plot(yrs, gmaod_cmip6[,wv], col="black", type="l", lwd=1.5, ylim=c(0,0.15), xlim=c(1,516), cex.lab=pcexlab, cex.main=pcexmain, cex.axis=pcexax,
              xlab = "Time (yr)", ylab = "AOD", main = "Global Mean AOD 530nm", lty=1, xaxt='n', xaxs="i")
axis(1, at=seq(1,516,12),labels=c(1961:2003), col.axis="black", cex.axis=pcexlab)
lines(yrs, gmaod_evah[,wv], col="red", lwd=1.5, lty=1)
lines(yrs, gmaod_eva[,wv], col="blue", lwd=1.5, lty=1)
lines(c(1:300)+216, gmaod_evah_carn[,wv], col="orange", lwd=1.5, lty=1)
legend(10, 0.16, legend=c("CMIP6", "EVA","EVA_H","EVA_H_Carn16"), col=c("black", "blue", "red","orange"), lty=1, cex=0.8, box.lty=0, y.intersp=0.6, seg.len=1)

# Figure 2 ############################################################
options(repr.plot.width = 12, repr.plot.height = 8, repr.plot.res = 250)

pcexlab=1.4
pcexmain=1.6
pcexax=1.2

# Colour levels:
bkr = c(0,0.25)
bkr_int = (bkr[2]-bkr[1])/20
brks_def<-c(seq(bkr[1],bkr[2],by=bkr_int))
colors = rev(inferno(20))
f <- colorRampPalette(colors[1:20])
jBrewColorsano <- c(f(length(brks_def)-1))
layout(matrix(c(1,2,3,4,5,6,7,8,9,10,10,10),4,3,byrow=T),heights=c(1,1,1,0.4))

tn=60

# Agung
t1=25
t2=t1+60-1

image(x=c(1:tn), y=lat_cmip6, z=(taod_cmip6[t1:t2,,11]), col=jBrewColorsano, xlab='Time (yr)', ylab='Latitude', main='a) CMIP6, Agung', 
      cex.lab=pcexlab, cex.main=pcexmain, cex.axis=pcexax, zlim=c(bkr[1],bkr[2]),breaks=brks_def, xlim=c(1,tn), xaxt='n')
axis(1, at=seq(1,72,12),labels=c(1963:1968), col.axis="black", cex.axis=pcexlab)
segments(0,30,tn,30, lty=2, lwd=0.6)
segments(0,-30,tn,-30, lty=2, lwd=0.6)


image(x=c(1:tn), y=lat_cmip6, z=(taod_eva[t1:t2,,11]), col=jBrewColorsano, xlab='Time (yr)', ylab='Latitude', main='b) EVA, Agung', 
      cex.lab=pcexlab, cex.main=pcexmain, cex.axis=pcexax, zlim=c(bkr[1],bkr[2]),breaks=brks_def, xlim=c(1,tn), xaxt='n')
axis(1, at=seq(1,72,12),labels=c(1963:1968), col.axis="black", cex.axis=pcexlab)
segments(0,30,tn,30, lty=2, lwd=0.6)
segments(0,-30,tn,-30, lty=2, lwd=0.6)


image(x=c(1:tn), y=lat_cmip6, z=(taod_evah[t1:t2,,11]), col=jBrewColorsano, xlab='Time (yr)', ylab='Latitude', main='c) EVA_H, Agung', 
      cex.lab=pcexlab, cex.main=pcexmain, cex.axis=pcexax, zlim=c(bkr[1],bkr[2]),breaks=brks_def, xlim=c(1,tn), xaxt='n')
axis(1, at=seq(1,72,12),labels=c(1963:1968), col.axis="black", cex.axis=pcexlab)
segments(0,30,tn,30, lty=2, lwd=0.6)
segments(0,-30,tn,-30, lty=2, lwd=0.6)

# El Chichon
t1=252
t2=t1+tn-1

image(x=c(1:tn), y=lat_cmip6, z=(taod_cmip6[t1:t2,,11]), col=jBrewColorsano, xlab='Time (yr)', ylab='Latitude', main='d) CMIP6, El Chichón', 
      cex.lab=pcexlab, cex.main=pcexmain, cex.axis=pcexax, zlim=c(bkr[1],bkr[2]),breaks=brks_def, xlim=c(1,tn), xaxt='n')
axis(1, at=seq(1,72,12),labels=c(1982:1987), col.axis="black", cex.axis=pcexlab)
segments(0,30,tn,30, lty=2, lwd=0.6)
segments(0,-30,tn,-30, lty=2, lwd=0.6)


image(x=c(1:tn), y=lat_cmip6, z=(taod_eva[t1:t2,,11]), col=jBrewColorsano, xlab='Time (yr)', ylab='Latitude', main='e) EVA, El Chichón', 
      cex.lab=pcexlab, cex.main=pcexmain, cex.axis=pcexax, zlim=c(bkr[1],bkr[2]),breaks=brks_def, xlim=c(1,tn), xaxt='n')
axis(1, at=seq(1,72,12),labels=c(1982:1987), col.axis="black", cex.axis=pcexlab)
segments(0,30,tn,30, lty=2, lwd=0.6)
segments(0,-30,tn,-30, lty=2, lwd=0.6)


image(x=c(1:tn), y=lat_cmip6, z=(taod_evah[t1:t2,,11]), col=jBrewColorsano, xlab='Time (yr)', ylab='Latitude', main='f) EVA_H, El Chichón', 
      cex.lab=pcexlab, cex.main=pcexmain, cex.axis=pcexax, zlim=c(bkr[1],bkr[2]),breaks=brks_def, xlim=c(1,tn), xaxt='n')
axis(1, at=seq(1,72,12),labels=c(1982:1987), col.axis="black", cex.axis=pcexlab)
segments(0,30,tn,30, lty=2, lwd=0.6)
segments(0,-30,tn,-30, lty=2, lwd=0.6)

# Pinatubo
t1=360
t2=t1+tn-1

image(x=c(1:tn), y=lat_cmip6, z=(taod_cmip6[t1:t2,,11]), col=jBrewColorsano, xlab='Time (yr)', ylab='Latitude', main='g) CMIP6, Pinatubo', 
      cex.lab=pcexlab, cex.main=pcexmain, cex.axis=pcexax, zlim=c(bkr[1],bkr[2]),breaks=brks_def, xlim=c(1,tn), xaxt='n')
axis(1, at=seq(1,72,12),labels=c(1991:1996), col.axis="black", cex.axis=pcexlab)
segments(0,30,tn,30, lty=2, lwd=0.6)
segments(0,-30,tn,-30, lty=2, lwd=0.6)


image(x=c(1:tn), y=lat_cmip6, z=(taod_eva[t1:t2,,11]), col=jBrewColorsano, xlab='Time (yr)', ylab='Latitude', main='h) EVA, Pinatubo', 
      cex.lab=pcexlab, cex.main=pcexmain, cex.axis=pcexax, zlim=c(bkr[1],bkr[2]),breaks=brks_def, xlim=c(1,tn), xaxt='n')
axis(1, at=seq(1,72,12),labels=c(1991:1996), col.axis="black", cex.axis=pcexlab)
segments(0,30,tn,30, lty=2, lwd=0.6)
segments(0,-30,tn,-30, lty=2, lwd=0.6)

image(x=c(1:tn), y=lat_cmip6, z=(taod_evah[t1:t2,,11]), col=jBrewColorsano, xlab='Time (yr)', ylab='Latitude', main='i) EVA_H, Pinatubo', 
      cex.lab=pcexlab, cex.main=pcexmain, cex.axis=pcexax, zlim=c(bkr[1],bkr[2]),breaks=brks_def, xlim=c(1,tn), xaxt='n')
axis(1, at=seq(1,72,12),labels=c(1991:1996), col.axis="black", cex.axis=pcexlab)
segments(0,30,tn,30, lty=2, lwd=0.6)
segments(0,-30,tn,-30, lty=2, lwd=0.6)

ColorBar(brks=brks_def, cols=colors, vert=F, draw_separators=T, label_scale=1.2, extra_margin=c(1,0,0,0), subsampleg=2)


#CMIP6
w2 = cos(lat_cmip6 * (pi/180))
dim(w2)
laod_cmip6 = apply(cmip6[,,13:24,], c(1,2,4), weighted.mean, w2[13:24])
dim(laod_cmip6)

# EVAH
w = cos((lat_evah) * (pi/180))
dim(w)
laod_evah = apply(evah[,,13:24,], c(1,2,4), weighted.mean, w[13:24])
dim(laod_evah)

#EVA
w2 = cos(lat_eva * (pi/180))
dim(w2)
laod_eva = apply(eva[,,13:24,], c(1,2,4), weighted.mean, w2[13:24])
dim(laod_eva)

# Figure 3 ############################################################
options(repr.plot.width = 12, repr.plot.height = 8, repr.plot.res = 250)

pcexlab=1.4
pcexmain=1.6
pcexax=1.2

# Colour levels:
bkr = (c(0,0.025))
bkr_int = (bkr[2]-bkr[1])/20
brks_def<-c(seq(bkr[1],bkr[2],by=bkr_int))
colors = rev(inferno(20))
f <- colorRampPalette(colors[1:20])
jBrewColorsano <- c(f(length(brks_def)-1))

layout(matrix(c(1,2,3,4,5,6,7,8,9,10,10,10),4,3,byrow=T),heights=c(1,1,1,0.4))

h1 = 15
h2 = 30

tn=60

# Agung
t1=25
t2=t1+60-1
image(x=c(1:tn), y=alt_cmip6[18,,1]/1000, z=laod_cmip6[t1:t2,,11], col=jBrewColorsano, xlab='Time (yr)', ylab='Alt. (km)', main='a) CMIP6, Agung', 
      cex.lab=pcexlab, cex.main=pcexmain, cex.axis=pcexax, zlim=c(bkr[1],bkr[2]),breaks=brks_def, xlim=c(1,tn), xaxt='n', ylim=c(h1,h2))
axis(1, at=seq(1,72,12),labels=c(1963:1968), col.axis="black", cex.axis=pcexlab)
lines(x=c(1:tn), y=alt_cmip6[18,Apply(laod_cmip6[t1:t2,,11], target_dims='lev', function(x)which(x==max(x), arr.ind=TRUE))$output,1]/1000, lty=2)

# El Chichon
t1=252
t2=t1+tn-1
image(x=c(1:tn), y=alt_cmip6[18,,1]/1000, z=laod_cmip6[t1:t2,,11], col=jBrewColorsano, xlab='Time (yr)', ylab='Alt. (km)', main='b) CMIP6, El Chichón', 
      cex.lab=pcexlab, cex.main=pcexmain, cex.axis=pcexax, zlim=c(bkr[1],bkr[2]),breaks=brks_def, xlim=c(1,tn), xaxt='n', ylim=c(h1,h2))
axis(1, at=seq(1,72,12),labels=c(1982:1987), col.axis="black", cex.axis=pcexlab)
lines(x=c(1:tn), y=alt_cmip6[18,Apply(laod_cmip6[t1:t2,,11], target_dims='lev', function(x)which(x==max(x), arr.ind=TRUE))$output,1]/1000, lty=2)

# Pinatubo
t1=360
t2=t1+tn-1
image(x=c(1:tn), y=alt_cmip6[18,,1]/1000, z=laod_cmip6[t1:t2,,11], col=jBrewColorsano, xlab='Time (yr)', ylab='Alt. (km)', main='c) CMIP6, Pinatubo', 
      cex.lab=pcexlab, cex.main=pcexmain, cex.axis=pcexax, zlim=c(bkr[1],bkr[2]),breaks=brks_def, xlim=c(1,tn), xaxt='n', ylim=c(h1,h2))
axis(1, at=seq(1,72,12),labels=c(1991:1996), col.axis="black", cex.axis=pcexlab)
lines(x=c(1:tn), y=alt_cmip6[18,Apply(laod_cmip6[t1:t2,,11], target_dims='lev', function(x)which(x==max(x), arr.ind=TRUE))$output,1]/1000, lty=2)

#################################
# Agung
t1=25
t2=t1+60-1
image(x=c(1:tn), y=alt_cmip6[18,,1]/1000, z=laod_eva[t1:t2,,11], col=jBrewColorsano, xlab='Time (yr)', ylab='Alt. (km)', main='d) EVA, Agung', 
      cex.lab=pcexlab, cex.main=pcexmain, cex.axis=pcexax, zlim=c(bkr[1],bkr[2]),breaks=brks_def, xlim=c(1,tn), xaxt='n', ylim=c(h1,h2))
axis(1, at=seq(1,72,12),labels=c(1963:1968), col.axis="black", cex.axis=pcexlab)
lines(x=c(1:tn), y=alt_cmip6[18,Apply(laod_eva[t1:t2,,11], target_dims='lev', function(x)which(x==max(x), arr.ind=TRUE))$output,1]/1000, lty=2)
   
# El Chichon
t1=252
t2=t1+tn-1
image(x=c(1:tn), y=alt_cmip6[18,,1]/1000, z=laod_eva[t1:t2,,11], col=jBrewColorsano, xlab='Time (yr)', ylab='Alt. (km)', main='e) EVA, El Chichón', 
      cex.lab=pcexlab, cex.main=pcexmain, cex.axis=pcexax, zlim=c(bkr[1],bkr[2]),breaks=brks_def, xlim=c(1,tn), xaxt='n', ylim=c(h1,h2))
axis(1, at=seq(1,72,12),labels=c(1982:1987), col.axis="black", cex.axis=pcexlab)
lines(x=c(1:tn), y=alt_cmip6[18,Apply(laod_eva[t1:t2,,11], target_dims='lev', function(x)which(x==max(x), arr.ind=TRUE))$output,1]/1000, lty=2)

# Pinatubo
t1=360
t2=t1+tn-1
image(x=c(1:tn), y=alt_cmip6[18,,1]/1000, z=laod_eva[t1:t2,,11], col=jBrewColorsano, xlab='Time (yr)', ylab='Alt. (km)', main='f) EVA, Pinatubo', 
      cex.lab=pcexlab, cex.main=pcexmain, cex.axis=pcexax, zlim=c(bkr[1],bkr[2]),breaks=brks_def, xlim=c(1,tn), xaxt='n', ylim=c(h1,h2))
axis(1, at=seq(1,72,12),labels=c(1991:1996), col.axis="black", cex.axis=pcexlab)
lines(x=c(1:tn), y=alt_cmip6[18,Apply(laod_eva[t1:t2,,11], target_dims='lev', function(x)which(x==max(x), arr.ind=TRUE))$output,1]/1000, lty=2)

#################################
# Agung
t1=25
t2=t1+60-1
image(x=c(1:tn), y=alt_cmip6[18,,1]/1000, z=laod_evah[t1:t2,,11], col=jBrewColorsano, xlab='Time (yr)', ylab='Alt. (km)', main='g) EVAH, Agung', 
      cex.lab=pcexlab, cex.main=pcexmain, cex.axis=pcexax, zlim=c(bkr[1],bkr[2]),breaks=brks_def, xlim=c(1,tn), xaxt='n', ylim=c(h1,h2))
axis(1, at=seq(1,72,12),labels=c(1963:1968), col.axis="black", cex.axis=pcexlab)
lines(x=c(1:tn), y=alt_cmip6[18,Apply(laod_evah[t1:t2,,11], target_dims='lev', function(x)which(x==max(x), arr.ind=TRUE))$output,1]/1000, lty=2)

# El Chichon
t1=252
t2=t1+tn-1
image(x=c(1:tn), y=alt_cmip6[18,,1]/1000, z=laod_evah[t1:t2,,11], col=jBrewColorsano, xlab='Time (yr)', ylab='Alt. (km)', main='h) EVAH, El Chichón', 
      cex.lab=pcexlab, cex.main=pcexmain, cex.axis=pcexax, zlim=c(bkr[1],bkr[2]),breaks=brks_def, xlim=c(1,tn), xaxt='n', ylim=c(h1,h2))
axis(1, at=seq(1,72,12),labels=c(1982:1987), col.axis="black", cex.axis=pcexlab)
lines(x=c(1:tn), y=alt_cmip6[18,Apply(laod_evah[t1:t2,,11], target_dims='lev', function(x)which(x==max(x), arr.ind=TRUE))$output,1]/1000, lty=2)

# Pinatubo
t1=360
t2=t1+tn-1
image(x=c(1:tn), y=alt_cmip6[18,,1]/1000, z=laod_evah[t1:t2,,11], col=jBrewColorsano, xlab='Time (yr)', ylab='Alt. (km)', main='i) EVAH, Pinatubo', 
      cex.lab=pcexlab, cex.main=pcexmain, cex.axis=pcexax, zlim=c(bkr[1],bkr[2]),breaks=brks_def, xlim=c(1,tn), xaxt='n', ylim=c(h1,h2))
axis(1, at=seq(1,72,12),labels=c(1991:1996), col.axis="black", cex.axis=pcexlab)
lines(x=c(1:tn), y=alt_cmip6[18,Apply(laod_evah[t1:t2,,11], target_dims='lev', function(x)which(x==max(x), arr.ind=TRUE))$output,1]/1000, lty=2)

ColorBar(brks=brks_def, cols=colors, vert=F, draw_separators=T, label_scale=1.2, extra_margin=c(1,0,0,0), subsampleg=2)

