################################################################################
## Script for producing figures in Bilbao et al. (2025) The sensitivity of 
## EC-Earth3 decadal predictions to the choice of volcanic forcing dataset: 
## Insights for the next major eruption.
## Script purpose: Figure 10
## Date: 03/2025
## Author: Roberto Bilbao (roberto.bilbao@bsc.es)
################################################################################

# Load libraries
library(maps)
library(RColorBrewer)
library(s2dv)
library(multiApply)
library(ncdf4)
library(startR)
library(boot)
library(ClimProjDiags)

# Path to data
pathdat = ''

#Load models:
var = 'tas'
n=1
t = 1
tn = 5

#EC-Earth
nc_data <- nc_open(paste0(pathdat,'ERA5_tasanom_volc_1-10.nc'))
var_era5 <- Reorder(ncvar_get(nc_data, 'tas', start=c(1,1,1,t), count=c(-1,-1,-1,tn)),c(3,4,2,1))
#var_era5 <- Reorder(ncvar_get(nc_data, 'tas', start=c(1,1,1,t), count=c(-1,-1,-1,tn)),c(3,2,1))
lon_had = ncvar_get(nc_data, "longitude")
lat_had = ncvar_get(nc_data, "latitude")
nc_close(nc_data)
names(dim(var_era5)) = c("sdate","time","latitude","longitude")
#names(dim(var_era5)) = c("sdate","latitude","longitude")
dim(var_era5)

era5 = MeanDims(var_era5,'time')
#era5 = drop(var_era5)
dim(era5)

res <- CDORemap(era5, lon_had, lat_had, grid=paste0(pathdat,'EC-Earth3_dcpp_tas_1971-2015_1deg.nc'), method='bil', crop=FALSE)
era5i = res$data_array
lon_int = as.vector(res$lons)
lat_int = as.vector(res$lats)
dim(era5i)

# Load prediction anomalies
load(paste0(pathdat,'tas_dcpp_anom_EVA_EVAH_yr1-5.Rdata'))

dcppA_anom_ens = MeanDims(dcppA_anom, 'memb')
dcppC_anom_ens = MeanDims(dcppC_anom, 'memb')
eva_anom_ens = MeanDims(eva_anom, 'memb')
evah_anom_ens = MeanDims(evah_anom, 'memb')
dim(dcppA_anom_ens)

dcppA_anom_q = Apply(dcppA_anom, target_dims='memb', function(x) (quantile(x,probs = c(.05, .95),na.rm=TRUE)))$output
dcppC_anom_q = Apply(dcppC_anom, target_dims='memb', function(x) (quantile(x,probs = c(.05, .95),na.rm=TRUE)))$output
eva_anom_q = Apply(eva_anom, target_dims='memb', function(x) (quantile(x,probs = c(.05, .95),na.rm=TRUE)))$output
evah_anom_q = Apply(evah_anom, target_dims='memb', function(x) (quantile(x,probs = c(.05, .95),na.rm=TRUE)))$output
dim(dcppA_anom_q)

# Obs outside percentiles
dcpp_A_i = (era5i < dcppA_anom_q[1,,,] | era5i > dcppA_anom_q[2,,,]) == 1
dcpp_C_i = (era5i < dcppC_anom_q[1,,,] | era5i > dcppC_anom_q[2,,,]) == 1
eva_i = (era5i < eva_anom_q[1,,,] | era5i > eva_anom_q[2,,,]) == 1
evah_i = (era5i < evah_anom_q[1,,,] | era5i > evah_anom_q[2,,,]) == 1

dcpp_C_i1 = (era5i[3,,] < dcppC_anom_q[1,3,,]) == 1
dcpp_C_i2 = (era5i[3,,] > dcppC_anom_q[2,3,,]) == 1
dcpp_C_i3 = (era5i[3,,] < dcppC_anom_q[1,3,,] | era5i[3,,] > dcppC_anom_q[2,3,,]) == 1

#Percentage of gridpoints outside percentiles
dcpp_A_i_s = Apply(dcpp_A_i, target_dims=c('latitude','longitude'), function(x) (sum(x,na.rm=TRUE)))$output/(180*360)*100
dcpp_C_i_s = Apply(dcpp_C_i, target_dims=c('latitude','longitude'), function(x) (sum(x,na.rm=TRUE)))$output/(180*360)*100
eva_i_s = Apply(eva_i, target_dims=c('latitude','longitude'), function(x) (sum(x,na.rm=TRUE)))$output/(180*360)*100
evah_i_s = Apply(evah_i, target_dims=c('latitude','longitude'), function(x) (sum(x,na.rm=TRUE)))$output/(180*360)*100

# RMSE
dcppA_rms = sqrt((dcppA_anom_ens-era5i)^2)
dcppC_rms = sqrt((dcppC_anom_ens-era5i)^2)
eva_rms = sqrt((eva_anom_ens-era5i)^2)
evah_rms = sqrt((evah_anom_ens-era5i)^2)

# Weighted RMSE
weighted.rmse <- function(actual, predicted, weight){
    sqrt(sum((predicted-actual)^2*weight,na.rm=TRUE)/sum(weight*(((predicted-actual)*0)+1),na.rm=TRUE))
}

wt <- InsertDim(cos(lat_ecearth*(pi/180)),2,360,'longitude')
dim(wt)

dcppA_wrms = c(1,2,3)
dcppC_wrms = c(1,2,3)
eva_wrms = c(1,2,3)
evah_wrms = c(1,2,3)
for (i in c(1:3)){
   dcppA_wrms[i] = weighted.rmse(era5i[i,,],dcppA_anom_ens[i,,],wt)
   dcppC_wrms[i] = weighted.rmse(era5i[i,,],dcppC_anom_ens[i,,],wt)
   eva_wrms[i] = weighted.rmse(era5i[i,,],eva_anom_ens[i,,],wt)
   evah_wrms[i] = weighted.rmse(era5i[i,,],evah_anom_ens[i,,],wt)
}

round(dcppA_wrms,2)
round(dcppC_wrms,2)
round(eva_wrms,2)
round(evah_wrms,2)

#Global mean
index = c('globalmean')
lons.min <- c(0)
lons.max <- c(360)
lats.min <- c(-90)
lats.max <- c(90)

i=1
era5i_reg <- ClimProjDiags::WeightedMean(data=era5i, lon=as.vector(lon_ecearth), lat=as.vector(lat_ecearth), region=c(lons.min[i],lons.max[i],lats.min[i],lats.max[i]), londim=3, latdim=2)
dcppA_reg <- ClimProjDiags::WeightedMean(data=dcppA_anom, lon=as.vector(lon_ecearth), lat=as.vector(lat_ecearth), region=c(lons.min[i],lons.max[i],lats.min[i],lats.max[i]), londim=4, latdim=3)
dcppC_reg <- ClimProjDiags::WeightedMean(data=dcppC_anom, lon=as.vector(lon_ecearth), lat=as.vector(lat_ecearth), region=c(lons.min[i],lons.max[i],lats.min[i],lats.max[i]), londim=4, latdim=3)
eva_reg <- ClimProjDiags::WeightedMean(data=eva_anom, lon=as.vector(lon_ecearth), lat=as.vector(lat_ecearth), region=c(lons.min[i],lons.max[i],lats.min[i],lats.max[i]), londim=4, latdim=3)
evah_reg <- ClimProjDiags::WeightedMean(data=evah_anom, lon=as.vector(lon_ecearth), lat=as.vector(lat_ecearth), region=c(lons.min[i],lons.max[i],lats.min[i],lats.max[i]), londim=4, latdim=3)

options(repr.plot.width = 12, repr.plot.height = 6.5, repr.plot.res = 200)

# Colour levels:
brks_def<-c(seq(-1,1,by=0.1))
colors<-readRDS(paste0(pathdat,'colorbar_21.RDS'))[1:20]
f <- colorRampPalette(colors[1:20])
jBrewColorsano <- c(f(length(brks_def)-1))

layout(matrix(c(1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,16,16,16,16),4,5,byrow=T),heights=c(5,5,5,2))

titscl = 0.7

#Models
n=1
PlotEquiMap(era5i[n,,], lon_ecearth, lat_ecearth, toptitle = 'a) ERA5 (1963-1967)', coast_width=0.5, axes_label_scale=0.8,
            title_scale= titscl, brks=brks_def,cols=jBrewColorsano, filled.continents=FALSE, drawleg=F, intylat=60, intxlon=60, colNA='lightgrey', col_inf=colors[1], col_sup=colors[20])

PlotEquiMap(dcppA_anom_ens[n,,], lon_ecearth, lat_ecearth, toptitle = paste0('b) DCPP-A, RMSE=',round(dcppA_wrms[n],2)), coast_width=0.5, axes_label_scale=0.8,
            title_scale= titscl, brks=brks_def,cols=jBrewColorsano, filled.continents=FALSE, drawleg=F, intylat=60, intxlon=60, colNA='lightgrey', col_inf=colors[1], col_sup=colors[20])
hatching(lats=lat_ecearth,lons=lon_ecearth,mask=t(dcpp_A_i[1,,]), dens = 30, lwd_size = 0.6, col='grey30', crosshatching=FALSE)
rect(xleft = 1, xright = 70, ybottom = -88, ytop = -63, col=adjustcolor("white",alpha.f=0.85), border = NA)
text(36, -76, paste0(round(dcpp_A_i_s[n],0),'%'), col='black', cex=1.5)

PlotEquiMap(dcppC_anom_ens[n,,], lon_ecearth, lat_ecearth, toptitle = paste0('c) DCPP-C, RMSE=',round(dcppC_wrms[n],2)), coast_width=0.5, axes_label_scale=0.8,
            title_scale= titscl, brks=brks_def,cols=jBrewColorsano, filled.continents=FALSE, drawleg=F, intylat=60, intxlon=60, colNA='lightgrey', col_inf=colors[1], col_sup=colors[20])
hatching(lats=lat_ecearth,lons=lon_ecearth,mask=t(dcpp_C_i[n,,]), dens = 30, lwd_size = 0.6, col='grey30', crosshatching=FALSE)
rect(xleft = 1, xright = 70, ybottom = -88, ytop = -63, col=adjustcolor("white",alpha.f=0.85), border = NA)
text(36, -76, paste0(round(dcpp_C_i_s[n],0),'%'), col='black', cex=1.5)

PlotEquiMap(eva_anom_ens[n,,], lon_ecearth, lat_ecearth, toptitle = paste0('d) EVA, RMSE=',round(eva_wrms[n],2)), coast_width=0.5, axes_label_scale=0.8,
            title_scale= titscl, brks=brks_def,cols=jBrewColorsano, filled.continents=FALSE, drawleg=F, intylat=60, intxlon=60, colNA='lightgrey', col_inf=colors[1], col_sup=colors[20])
hatching(lats=lat_ecearth,lons=lon_ecearth,mask=t(eva_i[n,,]), dens = 30, lwd_size = 0.6, col='grey30', crosshatching=FALSE)
rect(xleft = 1, xright = 70, ybottom = -88, ytop = -63, col=adjustcolor("white",alpha.f=0.85), border = NA)
text(36, -76, paste0(round(eva_i_s[n],0),'%'), col='black', cex=1.5)

PlotEquiMap(evah_anom_ens[n,,], lon_ecearth, lat_ecearth, toptitle = paste0('e) EVA_H, RMSE=',round(evah_wrms[n],2)), coast_width=0.5, axes_label_scale=0.8,
            title_scale= titscl, brks=brks_def,cols=jBrewColorsano, filled.continents=FALSE, drawleg=F, intylat=60, intxlon=60, colNA='lightgrey', col_inf=colors[1], col_sup=colors[20])
hatching(lats=lat_ecearth,lons=lon_ecearth,mask=t(evah_i[n,,]), dens = 30, lwd_size = 0.6, col='grey30', crosshatching=FALSE)
rect(xleft = 1, xright = 70, ybottom = -88, ytop = -63, col=adjustcolor("white",alpha.f=0.85), border = NA)
text(36, -76, paste0(round(evah_i_s[n],0),'%'), col='black', cex=1.5)

#Models
n=2
PlotEquiMap(era5i[n,,], lon_ecearth, lat_ecearth, toptitle = 'f) ERA5 (1982-1986)', coast_width=0.5, axes_label_scale=0.8,
            title_scale= titscl, brks=brks_def,cols=jBrewColorsano, filled.continents=FALSE, drawleg=F, intylat=60, intxlon=60, colNA='lightgrey', col_inf=colors[1], col_sup=colors[20])

PlotEquiMap(dcppA_anom_ens[n,,], lon_ecearth, lat_ecearth, toptitle = paste0('g) DCPP-A, RMSE=',round(dcppA_wrms[n],2)), coast_width=0.5, axes_label_scale=0.8,
            title_scale= titscl, brks=brks_def,cols=jBrewColorsano, filled.continents=FALSE, drawleg=F, intylat=60, intxlon=60, colNA='lightgrey', col_inf=colors[1], col_sup=colors[20])
hatching(lats=lat_ecearth,lons=lon_ecearth,mask=t(dcpp_A_i[2,,]), dens = 30, lwd_size = 0.6, col='grey30', crosshatching=FALSE)
rect(xleft = 1, xright = 70, ybottom = -88, ytop = -63, col=adjustcolor("white",alpha.f=0.85), border = NA)
text(36, -76, paste0(round(dcpp_A_i_s[n],0),'%'), col='black', cex=1.5)

PlotEquiMap(dcppC_anom_ens[n,,], lon_ecearth, lat_ecearth, toptitle = paste0('h) DCPP-C, RMSE=',round(dcppC_wrms[n],2)), coast_width=0.5, axes_label_scale=0.8,
            title_scale= titscl, brks=brks_def,cols=jBrewColorsano, filled.continents=FALSE, drawleg=F, intylat=60, intxlon=60, colNA='lightgrey', col_inf=colors[1], col_sup=colors[20])
hatching(lats=lat_ecearth,lons=lon_ecearth,mask=t(dcpp_C_i[n,,]), dens = 30, lwd_size = 0.6, col='grey30', crosshatching=FALSE)
rect(xleft = 1, xright = 70, ybottom = -88, ytop = -63, col=adjustcolor("white",alpha.f=0.85), border = NA)
text(36, -76, paste0(round(dcpp_C_i_s[n],0),'%'), col='black', cex=1.5)

PlotEquiMap(eva_anom_ens[n,,], lon_ecearth, lat_ecearth, toptitle = paste0('i) EVA, RMSE=',round(eva_wrms[n],2)), coast_width=0.5, axes_label_scale=0.8,
            title_scale= titscl, brks=brks_def,cols=jBrewColorsano, filled.continents=FALSE, drawleg=F, intylat=60, intxlon=60, colNA='lightgrey', col_inf=colors[1], col_sup=colors[20])
hatching(lats=lat_ecearth,lons=lon_ecearth,mask=t(eva_i[n,,]), dens = 30, lwd_size = 0.6, col='grey30', crosshatching=FALSE)
rect(xleft = 1, xright = 70, ybottom = -88, ytop = -63, col=adjustcolor("white",alpha.f=0.85), border = NA)
text(36, -76, paste0(round(eva_i_s[n],0),'%'), col='black', cex=1.5)

PlotEquiMap(evah_anom_ens[n,,], lon_ecearth, lat_ecearth, toptitle = paste0('i) EVA_H, RMSE=',round(evah_wrms[n],2)), coast_width=0.5, axes_label_scale=0.8,
            title_scale= titscl, brks=brks_def,cols=jBrewColorsano, filled.continents=FALSE, drawleg=F, intylat=60, intxlon=60, colNA='lightgrey', col_inf=colors[1], col_sup=colors[20])
hatching(lats=lat_ecearth,lons=lon_ecearth,mask=t(evah_i[n,,]), dens = 30, lwd_size = 0.6, col='grey30', crosshatching=FALSE)
rect(xleft = 1, xright = 70, ybottom = -88, ytop = -63, col=adjustcolor("white",alpha.f=0.85), border = NA)
text(36, -76, paste0(round(evah_i_s[n],0),'%'), col='black', cex=1.5)

#Models
n=3
PlotEquiMap(era5i[n,,], lon_ecearth, lat_ecearth, toptitle = 'k) ERA5 (1991-1995)', coast_width=0.5, axes_label_scale=0.8,
            title_scale= titscl, brks=brks_def,cols=jBrewColorsano, filled.continents=FALSE, drawleg=F, intylat=60, intxlon=60, colNA='lightgrey', col_inf=colors[1], col_sup=colors[20])

PlotEquiMap(dcppA_anom_ens[n,,], lon_ecearth, lat_ecearth, toptitle = paste0('l) DCPP-A, RMSE=',round(dcppA_wrms[n],2)), coast_width=0.5, axes_label_scale=0.8,
            title_scale= titscl, brks=brks_def,cols=jBrewColorsano, filled.continents=FALSE, drawleg=F, intylat=60, intxlon=60, colNA='lightgrey', col_inf=colors[1], col_sup=colors[20])
hatching(lats=lat_ecearth,lons=lon_ecearth,mask=t(dcpp_A_i[n,,]), dens = 30, lwd_size = 0.6, col='grey30', crosshatching=FALSE)
rect(xleft = 1, xright = 70, ybottom = -88, ytop = -63, col=adjustcolor("white",alpha.f=0.85), border = NA)
text(36, -76, paste0(round(dcpp_A_i_s[n],0),'%'), col='black', cex=1.5)

PlotEquiMap(dcppC_anom_ens[n,,], lon_ecearth, lat_ecearth, toptitle = paste0('m) DCPP-C, RMSE=',round(dcppC_wrms[n],2)), coast_width=0.5, axes_label_scale=0.8,
            title_scale= titscl, brks=brks_def,cols=jBrewColorsano, filled.continents=FALSE, drawleg=F, intylat=60, intxlon=60, colNA='lightgrey', col_inf=colors[1], col_sup=colors[20])
hatching(lats=lat_ecearth,lons=lon_ecearth,mask=t(dcpp_C_i[n,,]), dens = 30, lwd_size = 0.6, col='grey30', crosshatching=FALSE)
rect(xleft = 1, xright = 70, ybottom = -88, ytop = -63, col=adjustcolor("white",alpha.f=0.85), border = NA)
text(36, -76, paste0(round(dcpp_C_i_s[n],0),'%'), col='black', cex=1.5)

PlotEquiMap(eva_anom_ens[n,,], lon_ecearth, lat_ecearth, toptitle = paste0('n) EVA, RMSE=',round(eva_wrms[n],2)), coast_width=0.5, axes_label_scale=0.8,
            title_scale= titscl, brks=brks_def,cols=jBrewColorsano, filled.continents=FALSE, drawleg=F, intylat=60, intxlon=60, colNA='lightgrey', col_inf=colors[1], col_sup=colors[20])
hatching(lats=lat_ecearth,lons=lon_ecearth,mask=t(eva_i[n,,]), dens = 30, lwd_size = 0.6, col='grey30', crosshatching=FALSE)
rect(xleft = 1, xright = 70, ybottom = -88, ytop = -63, col=adjustcolor("white",alpha.f=0.85), border = NA)
text(36, -76, paste0(round(eva_i_s[n],0),'%'), col='black', cex=1.5)

PlotEquiMap(evah_anom_ens[n,,], lon_ecearth, lat_ecearth, toptitle = paste0('o) EVA_H, RMSE=',round(evah_wrms[n],2)), coast_width=0.5, axes_label_scale=0.8,
            title_scale= titscl, brks=brks_def,cols=jBrewColorsano, filled.continents=FALSE, drawleg=F, intylat=60, intxlon=60, colNA='lightgrey', col_inf=colors[1], col_sup=colors[20])
hatching(lats=lat_ecearth,lons=lon_ecearth,mask=t(evah_i[n,,]), dens = 30, lwd_size = 0.6, col='grey30', crosshatching=FALSE)
rect(xleft = 1, xright = 70, ybottom = -88, ytop = -63, col=adjustcolor("white",alpha.f=0.85), border = NA)
text(36, -76, paste0(round(evah_i_s[n],0),'%'), col='black', cex=1.5)

ColorBar(brks=brks_def, cols=colors, vert=F, draw_separators=T, label_scale=1, extra_margin=c(1,0,0,0), subsampleg=2, triangle_ends=c(T,T), col_inf=jBrewColorsano[1], col_sup=jBrewColorsano[20])