################################################################################
## Script for producing figures in Bilbao et al. (2025) The sensitivity of 
## EC-Earth3 decadal predictions to the choice of volcanic forcing dataset: 
## Insights for the next major eruption.
## Script purpose: Figure 4 tas
## Date: 03/2025
## Author: Roberto Bilbao (roberto.bilbao@bsc.es)
################################################################################

# Load libraries
library(s2dv)
library(multiApply)
library(ncdf4)
library(boot)

# Path to data
pathdat = ''

# Variable
var = 'ta50'

#DCPP-A
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_dcppA-hindcast_',reg,'.nc'))
dcppA <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(dcppA)) = c("memb","sdate","time")
dim(dcppA)

#DCPP-C
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_dcppC_hindcast_',reg,'.nc'))
dcppC <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(dcppC)) = c("memb","sdate","time")
dim(dcppC)

#EVA
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_EVA_',reg,'.nc'))
eva_dcpp <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(eva_dcpp)) = c("memb","sdate","time")
dim(eva_dcpp)

#EVA_H
nc_data <- nc_open(paste0(pathdat,'EC-Earth3',var,'_EVA_H_',reg,'.nc'))
evah_dcpp <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(evah_dcpp)) = c("memb","sdate","time")
dim(evah_dcpp)

#EVA_H_Carn16
nc_data <- nc_open(paste0(pathdat,'EC-Earth3',var,'_EVA_H_Carn16_',reg,'.nc'))
hud_dcpp <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(hud_dcpp)) = c("memb","time")
dim(hud_dcpp)

# Difference
dcpp_diff = dcppA-dcppC
eva_diff = eva_dcpp-dcppC
evah_diff = evah_dcpp-dcppC
hud_diff = hud_dcpp-dcppC[,3,]

# Ensemble mean
dcpp_diff_ens = MeanDims(dcpp_diff,'memb',na.rm = TRUE)
evah_diff_ens = MeanDims(evah_diff,'memb',na.rm = TRUE)
eva_diff_ens = MeanDims(eva_diff,'memb',na.rm = TRUE)
hud_diff_ens = MeanDims(hud_diff,'memb',na.rm = TRUE)

#Function
signif_boot <- function(data, Rpar, memb){
# Exp with ensemble members
# Rpar - number of repetitions
# memb - number of ensemble members
bootstrap = boot(data, function(x,i) (mean(x[i=c(sample(memb,size=memb,replace=TRUE))],na.rm = TRUE)), R=Rpar)$t   
signif <- apply(bootstrap,c(2), function(x) (quantile(x,0.025,na.rm=TRUE)>=0)||(quantile(x,0.975,na.rm=TRUE)<=0))
signif[signif == 0] = NA
return(signif)
}
                
Rpar=1000
dcpp_boot = apply(dcpp_diff, c(2,3), function(x) (signif_boot(x,Rpar,10)))
evah_boot = apply(evah_diff, c(2,3), function(x) (signif_boot(x,Rpar,10)))
eva_boot = apply(eva_diff, c(2,3), function(x) (signif_boot(x,Rpar,10)))
hud_boot = apply(hud_diff, c(2), function(x) (signif_boot(x,Rpar,10)))

#Spread 10th and 90th percentile
dcpp_perc = Apply(dcpp_diff, target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output
evah_perc = Apply(evah_diff, target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output
eva_perc = Apply(eva_diff, target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output
hud_perc = Apply(hud_diff, target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output            

options(repr.plot.width = 12, repr.plot.height = 3, repr.plot.res = 200)
par(mfrow=c(1,3))

#PLOT
pcexlab=1.6
pcexmain=1.6
pcexax=1.6

l1 = -0.8
l2 = 0.5

#Agung
yrs = c(1:108)
plot(yrs, dcpp_diff_ens[1,], col="black", type="l", lwd=1, ylim=c(l1,l2), xlim=c(1,108), cex.lab=pcexlab, cex.main=pcexmain, cex.axis=pcexax,
              xlab = "Time", ylab = "ΔT (°C)", main = "d) s1962, Agung", xaxt='n', xaxs="i")
lines(yrs,yrs*0, lty=2, col='black',lwd=1)
lines((c(-5:5)*0)+3,c(-5:5), lty=2, col='black',lwd=0.5)
axis(1, at=seq(1,108,12),labels=c(1963:1971), col.axis="black", cex.axis=pcexlab)

polygon(c(yrs,rev(yrs)), c(dcpp_perc[1,1,],rev(dcpp_perc[2,1,])),col =adjustcolor("grey",alpha.f=0.35), border = FALSE)
polygon(c(yrs,rev(yrs)), c(eva_perc[1,1,],rev(eva_perc[2,1,])),col =adjustcolor("lightblue",alpha.f=0.35), border = FALSE)
polygon(c(yrs,rev(yrs)), c(evah_perc[1,1,],rev(evah_perc[2,1,])),col =adjustcolor("pink",alpha.f=0.35), border = FALSE)

lines(yrs, dcpp_diff_ens[1,], col="black")
lines(yrs, eva_diff_ens[1,], col="blue")
lines(yrs, evah_diff_ens[1,], col="red")
lines(yrs, ((yrs*0)+l1+0.06)*dcpp_boot[1,], lty=1, col="black", lwd=0.5, type="p", pch=15, cex=0.5)
lines(yrs, ((yrs*0)+l1+0.03)*eva_boot[1,], lty=1, col="blue", lwd=0.5, type="p", pch=15, cex=0.5)
lines(yrs, ((yrs*0)+l1)*evah_boot[1,], lty=1, col="red", lwd=0.5, type="p", pch=15, cex=0.5)

#El Chichon
yrs = c(1:108)
plot(yrs, dcpp_diff_ens[2,], col="black", type="l", lwd=1, ylim=c(l1,l2), xlim=c(1,108), cex.lab=pcexlab, cex.main=pcexmain, cex.axis=pcexax,
              xlab = "Time", ylab = "ΔT (°C)", main = "e) s1981, El Chichon", xaxt='n', xaxs="i")
lines(yrs,yrs*0, lty=2, col='black',lwd=1)
lines((c(-5:5)*0)+3,c(-5:5), lty=2, col='black',lwd=0.5)
axis(1, at=seq(1,108,12),labels=c(1982:1990), col.axis="black", cex.axis=pcexlab)

polygon(c(yrs,rev(yrs)), c(dcpp_perc[1,2,],rev(dcpp_perc[2,2,])),col =adjustcolor("grey",alpha.f=0.35), border = FALSE)
polygon(c(yrs,rev(yrs)), c(eva_perc[1,2,],rev(eva_perc[2,2,])),col =adjustcolor("lightblue",alpha.f=0.35), border = FALSE)
polygon(c(yrs,rev(yrs)), c(evah_perc[1,2,],rev(evah_perc[2,2,])),col =adjustcolor("pink",alpha.f=0.35), border = FALSE)

lines(yrs, dcpp_diff_ens[2,], col="black")
lines(yrs, eva_diff_ens[2,], col="blue")
lines(yrs, evah_diff_ens[2,], col="red")

lines(yrs, ((yrs*0)+l1+0.06)*dcpp_boot[2,], lty=1, col="black", lwd=0.5, type="p", pch=15, cex=0.5)
lines(yrs, ((yrs*0)+l1+0.03)*eva_boot[2,], lty=1, col="blue", lwd=0.5, type="p", pch=15, cex=0.5)
lines(yrs, ((yrs*0)+l1)*evah_boot[2,], lty=1, col="red", lwd=0.5, type="p", pch=15, cex=0.5)

#Pinatubo
yrs = c(1:108)
plot(yrs, dcpp_diff_ens[3,], col="black", type="l", lwd=1, ylim=c(l1,l2), xlim=c(1,108), cex.lab=pcexlab, cex.main=pcexmain, cex.axis=pcexax,
              xlab = "Time", ylab = "ΔT (°C)", main = "f) s1990, Pinatubo", xaxt='n', xaxs="i")
lines(yrs,yrs*0, lty=2, col='black',lwd=1)
lines((c(-5:5)*0)+6,c(-5:5), lty=2, col='black',lwd=0.5)
axis(1, at=seq(1,108,12),labels=c(1991:1999), col.axis="black", cex.axis=pcexlab)

polygon(c(yrs,rev(yrs)), c(hud_perc[1,],rev(hud_perc[2,])),col =adjustcolor("lightgreen",alpha.f=0.35), border = FALSE)
polygon(c(yrs,rev(yrs)), c(dcpp_perc[1,3,],rev(dcpp_perc[2,3,])),col =adjustcolor("grey",alpha.f=0.35), border = FALSE)
polygon(c(yrs,rev(yrs)), c(eva_perc[1,3,],rev(eva_perc[2,3,])),col =adjustcolor("lightblue",alpha.f=0.35), border = FALSE)
polygon(c(yrs,rev(yrs)), c(evah_perc[1,3,],rev(evah_perc[2,3,])),col =adjustcolor("pink",alpha.f=0.35), border = FALSE)

lines(yrs, dcpp_diff_ens[3,], col="black")
lines(yrs, eva_diff_ens[3,], col="blue")
lines(yrs, evah_diff_ens[3,], col="red")
lines(yrs, hud_diff_ens, col="darkgreen")

lines(yrs, ((yrs*0)+l1+0.09)*dcpp_boot[3,], lty=1, col="black", lwd=0.5, type="p", pch=15, cex=0.5)
lines(yrs, ((yrs*0)+l1+0.06)*eva_boot[3,], lty=1, col="blue", lwd=0.5, type="p", pch=15, cex=0.5)
lines(yrs, ((yrs*0)+l1+0.03)*evah_boot[3,], lty=1, col="red", lwd=0.5, type="p", pch=15, cex=0.5)
lines(yrs, ((yrs*0)+l1)*hud_boot, lty=1, col="darkgreen", lwd=0.5, type="p", pch=15, cex=0.5)
