
################################################################################
## Script for producing figures in Bilbao et al. (2025) The sensitivity of 
## EC-Earth3 decadal predictions to the choice of volcanic forcing dataset: 
## Insights for the next major eruption.
## Script purpose: Figures 6 and 7
## Date: 03/2025
## Author: Roberto Bilbao (roberto.bilbao@bsc.es)
################################################################################

# Load libraries
library(maps)
library(RColorBrewer)
library(s2dv)
library(ncdf4)
library(ClimProjDiags)

# Path to data
pathdat = ''

# Load data generated with tas_diff_maps_data.R
#Fig 6:
load(paste0(pathdat,'tas_dcpp_EVA_EVAH_yr1.Rdata'))

#Fig 7:
#load(paste0(pathdat,'tas_dcpp_EVA_EVAH_yr2-5.Rdata'))

#Regional means
index = c('globalmean','nino34','tropics','TropPac','SPNA','NAtl','NH','SH','NHLat','SHLat')
lons.min <- c(0,190,0,160,300,280,0,0,0,0)
lons.max <- c(360,240,360,280,350,360,360,360,360,360)
lats.min <- c(-90,-5,-30,-20,50,0,0,-90,30,-90)
lats.max <- c(90,5,30,20,65,65,90,0,90,-30)

i=1
diff_dcpp_tm_reg <- WeightedMean(data=diff_dcpp_ens, lon=as.vector(lon_ecearth), lat=as.vector(lat_ecearth), region=c(lons.min[i],lons.max[i],lats.min[i],lats.max[i]), londim=3, latdim=2)
diff_eva_tm_reg <- WeightedMean(data=diff_eva_ens, lon=as.vector(lon_ecearth), lat=as.vector(lat_ecearth), region=c(lons.min[i],lons.max[i],lats.min[i],lats.max[i]), londim=3, latdim=2)
diff_evah_tm_reg <- WeightedMean(data=diff_evah_ens, lon=as.vector(lon_ecearth), lat=as.vector(lat_ecearth), region=c(lons.min[i],lons.max[i],lats.min[i],lats.max[i]), londim=3, latdim=2)

# Plot
#Shift lons
shft = 110

diff_dcpp_ens_shft = abind(diff_dcpp_ens[,,shft:360], diff_dcpp_ens[,,1:(shft-1)], along=3)
diff_eva_ens_shft = abind(diff_eva_ens[,,shft:360], diff_eva_ens[,,1:(shft-1)], along=3)
diff_evah_ens_shft = abind(diff_evah_ens[,,shft:360], diff_evah_ens[,,1:(shft-1)], along=3)

dcpp_boot_shft = abind(dcpp_boot[,,shft:360], dcpp_boot[,,1:(shft-1)], along=3)
evah_boot_shft = abind(evah_boot[,,shft:360], evah_boot[,,1:(shft-1)], along=3)
eva_boot_shft = abind(eva_boot[,,shft:360], eva_boot[,,1:(shft-1)], along=3)

options(repr.plot.width = 12, repr.plot.height = 9, repr.plot.res = 200)

# Colour levels:
brks_def<-c(seq(-1,1,by=0.1))
colors<-readRDS('/esarchive/scratch/Earth/rfernand/dcpp/colorbar_21.RDS')[1:20]
f <- colorRampPalette(colors[1:20])
jBrewColorsano <- c(f(length(brks_def)-1))


layout(matrix(c(1,2,3,4,5,6,7,8,9,10,10,10),4,3,byrow=T),heights=c(5,5,5,2))

#DCPP
PlotEquiMap(diff_dcpp_ens_shft[1,,], lon_ecearth+shft, lat_ecearth, toptitle = paste0('a) Agung (1963), ΔT=',round(diff_dcpp_tm_reg[1],2)), coast_width=0.01, axes_label_scale=1,
            title_scale= 1, brks=brks_def,cols=jBrewColorsano, filled.continents=FALSE, drawleg=F, intylat=60, intxlon=60, 
            colNA='lightgrey', col_inf=colors[1], col_sup=colors[20], xlonshft=10, xlabels=c('120E','180','120W','60W','0','60E',''))#, dots=mm_sign[1,,], dot_symbol = 16, dot_size = 0.2)
map(wrap = c(0+shft-1,360+shft-1), fill=FALSE, add=T, boundary=T,interior=F, lwd=0.8)
hatching(lats=lat_ecearth,lons=lon_ecearth+shft,mask=t(dcpp_boot_shft[1,,]), dens = 20, lwd_size = 0.6, col='black', crosshatching=FALSE)

PlotEquiMap(diff_dcpp_ens_shft[2,,], lon_ecearth+shft, lat_ecearth, toptitle = paste0('b) El Chichon (1982), ΔT=',round(diff_dcpp_tm_reg[2],2)), coast_width=0.01, axes_label_scale=1,
            title_scale= 1, brks=brks_def,cols=jBrewColorsano, filled.continents=FALSE, drawleg=F, intylat=60, intxlon=60, 
            colNA='lightgrey', col_inf=colors[1], col_sup=colors[20], xlonshft=10, xlabels=c('120E','180','120W','60W','0','60E',''))#, dots=mm_sign[1,,], dot_symbol = 16, dot_size = 0.2)
map(wrap = c(0+shft-1,360+shft-1), fill=FALSE, add=T, boundary=T,interior=F, lwd=0.8)
hatching(lats=lat_ecearth,lons=lon_ecearth+shft,mask=t(dcpp_boot_shft[2,,]), dens = 20, lwd_size = 0.6, col='black', crosshatching=FALSE)

PlotEquiMap(diff_dcpp_ens_shft[3,,], lon_ecearth+shft, lat_ecearth, toptitle = paste0('c) Pinatubo (1991), ΔT=',round(diff_dcpp_tm_reg[3],2)), coast_width=0.01, axes_label_scale=1,
            title_scale= 1, brks=brks_def,cols=jBrewColorsano, filled.continents=FALSE, drawleg=F, intylat=60, intxlon=60, 
            colNA='lightgrey', col_inf=colors[1], col_sup=colors[20], xlonshft=10, xlabels=c('120E','180','120W','60W','0','60E',''))#, dots=mm_sign[1,,], dot_symbol = 16, dot_size = 0.2)
map(wrap = c(0+shft-1,360+shft-1), fill=FALSE, add=T, boundary=T,interior=F, lwd=0.8)
hatching(lats=lat_ecearth,lons=lon_ecearth+shft,mask=t(dcpp_boot_shft[3,,]), dens = 20, lwd_size = 0.6, col='black', crosshatching=FALSE)

#EVA
PlotEquiMap(diff_eva_ens_shft[1,,], lon_ecearth+shft, lat_ecearth, toptitle = paste0('d) Agung (1963), ΔT=',round(diff_eva_tm_reg[1],2)), coast_width=0.01, axes_label_scale=1,
            title_scale= 1, brks=brks_def,cols=jBrewColorsano, filled.continents=FALSE, drawleg=F, intylat=60, intxlon=60, 
            colNA='lightgrey', col_inf=colors[1], col_sup=colors[20], xlonshft=10, xlabels=c('120E','180','120W','60W','0','60E',''))#, dots=mm_sign[1,,], dot_symbol = 16, dot_size = 0.2)
map(wrap = c(0+shft-1,360+shft-1), fill=FALSE, add=T, boundary=T,interior=F, lwd=0.8)
hatching(lats=lat_ecearth,lons=lon_ecearth+shft,mask=t(eva_boot_shft[1,,]), dens = 20, lwd_size = 0.6, col='black', crosshatching=FALSE)

PlotEquiMap(diff_eva_ens_shft[2,,], lon_ecearth+shft, lat_ecearth, toptitle = paste0('e) El Chichon (1982), ΔT=',round(diff_eva_tm_reg[2],2)), coast_width=0.01, axes_label_scale=1,
            title_scale= 1, brks=brks_def,cols=jBrewColorsano, filled.continents=FALSE, drawleg=F, intylat=60, intxlon=60, 
            colNA='lightgrey', col_inf=colors[1], col_sup=colors[20], xlonshft=10, xlabels=c('120E','180','120W','60W','0','60E',''))#, dots=mm_sign[1,,], dot_symbol = 16, dot_size = 0.2)
map(wrap = c(0+shft-1,360+shft-1), fill=FALSE, add=T, boundary=T,interior=F, lwd=0.8)
hatching(lats=lat_ecearth,lons=lon_ecearth+shft,mask=t(eva_boot_shft[2,,]), dens = 20, lwd_size = 0.6, col='black', crosshatching=FALSE)

PlotEquiMap(diff_eva_ens_shft[3,,], lon_ecearth+shft, lat_ecearth, toptitle = paste0('f) Pinatubo (1991), ΔT=',round(diff_eva_tm_reg[3],2)), coast_width=0.01, axes_label_scale=1,
            title_scale= 1, brks=brks_def,cols=jBrewColorsano, filled.continents=FALSE, drawleg=F, intylat=60, intxlon=60, 
            colNA='lightgrey', col_inf=colors[1], col_sup=colors[20], xlonshft=10, xlabels=c('120E','180','120W','60W','0','60E',''))#, dots=mm_sign[1,,], dot_symbol = 16, dot_size = 0.2)
map(wrap = c(0+shft-1,360+shft-1), fill=FALSE, add=T, boundary=T,interior=F, lwd=0.8)
hatching(lats=lat_ecearth,lons=lon_ecearth+shft,mask=t(eva_boot_shft[3,,]), dens = 20, lwd_size = 0.6, col='black', crosshatching=FALSE)

#EVAH
PlotEquiMap(diff_evah_ens_shft[1,,], lon_ecearth+shft, lat_ecearth, toptitle = paste0('g) Agung (1963), ΔT=',round(diff_evah_tm_reg[1],2)), coast_width=0.01, axes_label_scale=1,
            title_scale= 1, brks=brks_def,cols=jBrewColorsano, filled.continents=FALSE, drawleg=F, intylat=60, intxlon=60, 
            colNA='lightgrey', col_inf=colors[1], col_sup=colors[20], xlonshft=10, xlabels=c('120E','180','120W','60W','0','60E',''))#, dots=mm_sign[1,,], dot_symbol = 16, dot_size = 0.2)
map(wrap = c(0+shft-1,360+shft-1), fill=FALSE, add=T, boundary=T,interior=F, lwd=0.8)
hatching(lats=lat_ecearth,lons=lon_ecearth+shft,mask=t(evah_boot_shft[1,,]), dens = 20, lwd_size = 0.6, col='black', crosshatching=FALSE)

PlotEquiMap(diff_evah_ens_shft[2,,], lon_ecearth+shft, lat_ecearth, toptitle = paste0('h) El Chichon (1982), ΔT=',round(diff_evah_tm_reg[2],2)), coast_width=0.01, axes_label_scale=1,
            title_scale= 1, brks=brks_def,cols=jBrewColorsano, filled.continents=FALSE, drawleg=F, intylat=60, intxlon=60, 
            colNA='lightgrey', col_inf=colors[1], col_sup=colors[20], xlonshft=10, xlabels=c('120E','180','120W','60W','0','60E',''))#, dots=mm_sign[1,,], dot_symbol = 16, dot_size = 0.2)
map(wrap = c(0+shft-1,360+shft-1), fill=FALSE, add=T, boundary=T,interior=F, lwd=0.8)
hatching(lats=lat_ecearth,lons=lon_ecearth+shft,mask=t(evah_boot_shft[2,,]), dens = 20, lwd_size = 0.6, col='black', crosshatching=FALSE)

PlotEquiMap(diff_evah_ens_shft[3,,], lon_ecearth+shft, lat_ecearth, toptitle = paste0('i) Pinatubo (1991), ΔT=',round(diff_evah_tm_reg[3],2)), coast_width=0.01, axes_label_scale=1,
            title_scale= 1, brks=brks_def,cols=jBrewColorsano, filled.continents=FALSE, drawleg=F, intylat=60, intxlon=60, 
            colNA='lightgrey', col_inf=colors[1], col_sup=colors[20], xlonshft=10, xlabels=c('120E','180','120W','60W','0','60E',''))#, dots=mm_sign[1,,], dot_symbol = 16, dot_size = 0.2)
map(wrap = c(0+shft-1,360+shft-1), fill=FALSE, add=T, boundary=T,interior=F, lwd=0.8)
hatching(lats=lat_ecearth,lons=lon_ecearth+shft,mask=t(evah_boot_shft[3,,]), dens = 20, lwd_size = 0.6, col='black', crosshatching=FALSE)

ColorBar(brks=brks_def, cols=colors, vert=F, draw_separators=T, label_scale=1.5, extra_margin=c(1,0,0,0), subsampleg=2, triangle_ends=c(T,T), col_inf=jBrewColorsano[1], col_sup=jBrewColorsano[20])