################################################################################
## Script for producing figures in Bilbao et al. (2025) The sensitivity of 
## EC-Earth3 decadal predictions to the choice of volcanic forcing dataset: 
## Insights for the next major eruption.
## Script purpose: Figure 8 tas
## Date: 03/2025
## Author: Roberto Bilbao (roberto.bilbao@bsc.es)
################################################################################

# Load libraries
library(maps)
library(RColorBrewer)
library(s2dv)
library(multiApply)
library(ncdf4)
library(boot)

# Path to data
pathdat = ''

# Variable
var = 'tas'

# Region
reg = 'globalmean'

#ERA5
nc_data <- nc_open(paste0(pathdat,'ERA5_tas_anom_',reg,'.nc'))
var_era5 <- ncvar_get(nc_data, var)
nc_close(nc_data)
names(dim(var_era5)) = c("sdate","time")
dim(var_era5)

#DCPP-A
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_dcppA-hindcast_anom_',reg,'.nc'))
dcppA <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(dcppA)) = c("memb","sdate","time")
dim(dcppA)

#DCPP-C
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_dcppC_hindcast_anom_',reg,'.nc'))
dcppC <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(dcppC)) = c("memb","sdate","time")
dim(dcppC)

#EVA
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_EVA_anom_',reg,'.nc'))
eva_dcpp <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(eva_dcpp)) = c("memb","sdate","time")
dim(eva_dcpp)

#EVA_H
nc_data <- nc_open(paste0(pathdat,'EC-Earth3',var,'_EVA_H_anom_',reg,'.nc'))
evah_dcpp <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(evah_dcpp)) = c("memb","sdate","time")
dim(evah_dcpp)

#EVA_H_Carn16
nc_data <- nc_open(paste0(pathdat,'EC-Earth3',var,'_EVA_H_Carn16_anom_',reg,'.nc'))
hud_dcpp <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(hud_dcpp)) = c("memb","time")
dim(hud_dcpp)

# Ensemble mean
dcppA_ens = MeanDims(dcppA,'memb',na.rm = TRUE)
dcppC_ens = MeanDims(dcppC,'memb',na.rm = TRUE)
evah_ens = MeanDims(evah_dcpp,'memb',na.rm = TRUE)
eva_ens = MeanDims(eva_dcpp,'memb',na.rm = TRUE)
hud_ens = MeanDims(hud_dcpp,'memb',na.rm = TRUE)

#Spread 2 10th and 90th percentile
perc_dcppA = Apply(dcppA, target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output
perc_dcppC = Apply(dcppC, target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output
perc_evah = Apply(evah_dcpp, target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output
perc_eva = Apply(eva_dcpp, target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output
perc_hud = Apply(hud_dcpp, target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output            

options(repr.plot.width = 12, repr.plot.height = 3, repr.plot.res = 300)
par(mfrow=c(1,3), cex=0.65)

pcexlab=1.6
pcexmain=1.8
pcexax=1.6


n=108
yrs = c(1:n)

## Agung
l1 = -0.8
l2 = 0.4
plot(yrs, var_era5[1,1:108], col="black", type="l", lwd=1.5, ylim=c(l1,l2), xlim=c(1,n-12), cex.lab=pcexlab, cex.main=pcexmain, cex.axis=pcexax,
              xlab = "Year", ylab = "ΔT (°C)", main = "g) s1962, Agung", lty=c("99"), pch=21, xaxt='n',xaxs="i")
axis(1, at=seq(from = 0, to = 120, by = 12),labels=c('1963','1964','1965','1966','1967','1968','1969','1970','1971','1972','1973'), col.axis="black", cex.axis=pcexlab)

polygon(c(yrs,rev(yrs)), c(perc_dcppA[1,1,1:108],rev(perc_dcppA[2,1,1:108])),col =adjustcolor("grey",alpha.f=0.35), border = FALSE)
polygon(c(yrs,rev(yrs)), c(perc_dcppC[1,1,1:108],rev(perc_dcppC[2,1,1:108])),col =adjustcolor("lightsalmon",alpha.f=0.35), border = FALSE)
polygon(c(yrs,rev(yrs)), c(perc_evah[1,1,1:108],rev(perc_evah[2,1,1:108])),col =adjustcolor("pink",alpha.f=0.35), border = FALSE)
polygon(c(yrs,rev(yrs)), c(perc_eva[1,1,1:108],rev(perc_eva[2,1,1:108])),col =adjustcolor("lightblue",alpha.f=0.25), border = FALSE)

lines(yrs, yrs*0, lty=2, col="black", lwd=0.5)
lines(yrs, ec_dcppA_ens[1,1:108], lty=1, col="black", lwd=1, type="l", pch=21)
lines(yrs, ec_dcppC_ens[1,1:108], lty=1, col="orange", lwd=1, type="l", pch=21)
lines(yrs, evah_dcpp_ens[1,1:108], lty=1, col="red", lwd=1, type="l", pch=21)
lines(yrs, eva_dcpp_ens[1,1:108], lty=1, col="blue", lwd=1, type="l", pch=21)
lines(yrs, var_era5[1,1:108], lty="99", col="black", lwd=1, type="l", pch=21)

## El Chichon
l1 = -0.5
l2 = 0.4
plot(yrs, var_era5[2,1:108], col="black", type="l", lwd=1.5, ylim=c(l1,l2), xlim=c(1,n-12), cex.lab=pcexlab, cex.main=pcexmain, cex.axis=pcexax,
              xlab = "Year", ylab = "ΔT (°C)", main = "h) s1981, El Chichón", lty=c("99"), pch=21, xaxt='n',xaxs="i")
axis(1, at=seq(from = 0, to = 120, by = 12),labels=c('1982','1983','1984','1985','1986','1987','1988','1989','1990','1991','1992'), col.axis="black", cex.axis=pcexlab)

polygon(c(yrs,rev(yrs)), c(perc_dcppA[1,2,1:108],rev(perc_dcppA[2,2,1:108])),col =adjustcolor("grey",alpha.f=0.35), border = FALSE)
polygon(c(yrs,rev(yrs)), c(perc_dcppC[1,2,1:108],rev(perc_dcppC[2,2,1:108])),col =adjustcolor("lightsalmon",alpha.f=0.35), border = FALSE)
polygon(c(yrs,rev(yrs)), c(perc_evah[1,2,1:108],rev(perc_evah[2,2,1:108])),col =adjustcolor("pink",alpha.f=0.35), border = FALSE)
polygon(c(yrs,rev(yrs)), c(perc_eva[1,2,1:108],rev(perc_eva[2,2,1:108])),col =adjustcolor("lightblue",alpha.f=0.25), border = FALSE)

lines(yrs, yrs*0, lty=2, col="black", lwd=0.5)
lines(yrs, ec_dcppA_ens[2,1:108], lty=1, col="black", lwd=1, type="l", pch=21)
lines(yrs, ec_dcppC_ens[2,1:108], lty=1, col="orange", lwd=1, type="l", pch=21)
lines(yrs, evah_dcpp_ens[2,1:108], lty=1, col="red", lwd=1, type="l", pch=21)
lines(yrs, eva_dcpp_ens[2,1:108], lty=1, col="blue", lwd=1, type="l", pch=21)
lines(yrs, var_era5[2,1:108], lty="99", col="black", lwd=1, type="l", pch=21)

## Pinatubo
l1 = -0.6
l2 = 0.6
plot(yrs, var_era5[3,1:108], col="black", type="l", lwd=1, ylim=c(l1,l2), xlim=c(1,n-12), cex.lab=pcexlab, cex.main=pcexmain, cex.axis=pcexax,
              xlab = "Year", ylab = "ΔT (°C)", main = "i) s1990, Pinatubo", lty=c("99"), pch=21, xaxt='n',xaxs="i")
axis(1, at=seq(from = 0, to = 120, by = 12),labels=c('1991','1992','1993','1994','1995','1996','1997','1998','1999','2000','2001'), col.axis="black", cex.axis=pcexlab)

polygon(c(yrs,rev(yrs)), c(perc_hud[1,1:108],rev(perc_hud[2,1:108])),col =adjustcolor("lightgreen",alpha.f=0.35), border = FALSE)
polygon(c(yrs,rev(yrs)), c(perc_dcppA[1,3,1:108],rev(perc_dcppA[2,3,1:108])),col =adjustcolor("grey",alpha.f=0.35), border = FALSE)
polygon(c(yrs,rev(yrs)), c(perc_dcppC[1,3,1:108],rev(perc_dcppC[2,3,1:108])),col =adjustcolor("lightsalmon",alpha.f=0.35), border = FALSE)
polygon(c(yrs,rev(yrs)), c(perc_evah[1,3,1:108],rev(perc_evah[2,3,1:108])),col =adjustcolor("pink",alpha.f=0.35), border = FALSE)
polygon(c(yrs,rev(yrs)), c(perc_eva[1,3,1:108],rev(perc_eva[2,3,1:108])),col =adjustcolor("lightblue",alpha.f=0.25), border = FALSE)

lines(yrs, yrs*0, lty=2, col="black", lwd=0.5)
lines(yrs, ec_dcppA_ens[3,1:108], lty=1, col="black", lwd=1, type="l", pch=21)
lines(yrs, ec_dcppC_ens[3,1:108], lty=1, col="orange", lwd=1, type="l", pch=21)
lines(yrs, evah_dcpp_ens[3,1:108], lty=1, col="red", lwd=1, type="l", pch=21)
lines(yrs, eva_dcpp_ens[3,1:108], lty=1, col="blue", lwd=1, type="l", pch=21)
lines(yrs, hud_dcpp_ens[1:108], lty=1, col="darkgreen", lwd=1, type="l", pch=21)
lines(yrs, var_era5[3,1:108], lty="99", col="black", lwd=1, type="l", pch=21)

legend(0, -0.35, legend=c(" ","ERA5"), 
       col=c("white","black"), lwd=1.5, lty='99', bty="n", 
       y.intersp = 2.6, x.intersp=0.2, text.width=1, cex=1.3, seg.len=0.4)

legend(22, -0.35, legend=c("DCPP-A","DCPP-C"), 
       col=c("black","orange"), lwd=1.5, lty=1, bty="n", 
       y.intersp = 2.6, x.intersp=0.2, text.width=1, cex=1.3, seg.len=0.4)

legend(49, -0.28, legend=c('DCPP_EVA',"DCPP_EVAH","DCPP_EVAH_Hud"),
       col=c('blue','red',"darkgreen"), lwd=1.5, lty=c(1,1), bty="n", 
       y.intersp = 2.6, x.intersp=0.2, text.width=1, cex=1.2, seg.len=0.4)
