################################################################################
## Script for producing figures in Bilbao et al. (2025) The sensitivity of 
## EC-Earth3 decadal predictions to the choice of volcanic forcing dataset: 
## Insights for the next major eruption.
## Script purpose: Figure 8 toa
## Date: 03/2025
## Author: Roberto Bilbao (roberto.bilbao@bsc.es)
################################################################################

# Load libraries
library(maps)
library(RColorBrewer)
library(s2dv)
library(multiApply)
library(ncdf4)
library(boot)

# Path to data
pathdat = ''

# Region
reg = 'globalmean'

#TOA DEEP-C Obs 
nc_data <- nc_open(pathdat,'DEEP-C_TOA_NET_v5_1985-2020.nc')
toa <- Reorder(ncvar_get(nc_data, "NET"),c(3,2,1))
lat = ncvar_get(nc_data, "lat")
lon = ncvar_get(nc_data, "lon")
nc_close(nc_data)
names(dim(toa)) = c("time","lat","lon")

# Compute Spatial Mean
index = c('globalmean','nino34','tropics','AMV1','AMV2','SPG','LabSea','TropPac','TropPacE','TropPacW')
lons.min <- c(0,190,0,0,280,300,302,150,215,150)
lons.max <- c(360,240,360,360,360,350,317,280,280,215)
lats.min <- c(-90,-5,-30,-60,0,50,52,-5,-5,-5)
lats.max <- c(90,5,30,60,60,65,65,5,5,5)
i=1
toa_gb <- ClimProjDiags::WeightedMean(data=toa, lon=as.vector(lon), lat=as.vector(lat), region=c(lons.min[i],lons.max[i],lats.min[i],lats.max[i]), londim=3, latdim=2)
toa_gb2 = toa_gb[1:420]
dim(toa_gb2) = c(12,35)
names(dim(toa_gb2)) = c("mon","yr")

#Clim
clim_toa = MeanDims(toa_gb2[,1:30],'yr')

#Anom
anom_toa = toa_gb2 - InsertDim(clim_toa,2,35,'yr')
dim(anom_toa)

anom_toa2 = anom_toa
dim(anom_toa2) = c(420)

anom_toa_obs_pina = anom_toa2[73:(73+120-1)]

#ERA5
nc_data <- nc_open(paste0(pathdat,'ERA5_rlut_anom_',reg,'.nc'))
rlut_era5 <- ncvar_get(nc_data, var)
nc_close(nc_data)
names(dim(rlut_era5)) = c("sdate","time")
dim(rlut_era5)

nc_data <- nc_open(paste0(pathdat,'ERA5_tsr_anom_',reg,'.nc'))
tsr_era5 <- ncvar_get(nc_data, var)
nc_close(nc_data)
names(dim(tsr_era5)) = c("sdate","time")
dim(tsr_era5)

toa_era5 = tsr_era5 + rlut_era5

#DCPP-A
var = 'rsdt'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_dcppA-hindcast_anom_',reg,'.nc'))
dcppA_rsdt <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(dcppA_rsdt)) = c("memb","sdate","time")
dim(dcppA_rsdt)

var = 'rsut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_dcppA-hindcast_anom_',reg,'.nc'))
dcppA_rsut <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(dcppA_rsut)) = c("memb","sdate","time")
dim(dcppA_rsut)

var = 'rlut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_dcppA-hindcast_anom_',reg,'.nc'))
dcppA_rlut <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(dcppA_rlut)) = c("memb","sdate","time")
dim(dcppA_rlut)

dcppA_anom = dcppA_rsdt-(dcppA_rlut+dcppA_rsut)

#DCPP-C
var = 'rsdt'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_dcppC-hindcast_anom_',reg,'.nc'))
dcppC_rsdt <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(dcppC_rsdt)) = c("memb","sdate","time")
dim(dcppC_rsdt)

var = 'rsut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_dcppC-hindcast_anom_',reg,'.nc'))
dcppC_rsut <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(dcppC_rsut)) = c("memb","sdate","time")
dim(dcppC_rsut)

var = 'rlut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_dcppC-hindcast_anom_',reg,'.nc'))
dcppC_rlut <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(dcppC_rlut)) = c("memb","sdate","time")
dim(dcppC_rlut)

dcppC_anom = dcppC_rsdt-(dcppC_rlut+dcppC_rsut)

#EVA
var = 'rsdt'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_EVA_anom_',reg,'.nc'))
eva_rsdt <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(eva_rsdt)) = c("memb","sdate","time")
dim(eva_rsdt)

var = 'rlut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_EVA_anom_',reg,'.nc'))
eva_rlut <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(eva_rlut)) = c("memb","sdate","time")
dim(eva_rlut)

var = 'rsut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_EVA_anom_',reg,'.nc'))
eva_rsut <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(eva_rsut)) = c("memb","sdate","time")
dim(eva_rsut)

eva_anom = eva_rsdt-(eva_rlut+eva_rsut)

#EVAH
var = 'rsdt'
nc_data <- nc_open(paste0(path_'EC-Earth3_',var,'_EVA_H_anom_',reg,'.nc'))
evah_rsdt <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(evah_rsdt)) = c("memb","sdate","time")
dim(evah_rsdt)

var = 'rlut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_EVA_H_anom_',reg,'.nc'))
evah_rlut <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(evah_rlut)) = c("memb","sdate","time")
dim(evah_rlut)

var = 'rsut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_EVA_H_anom_',reg,'.nc'))
evah_rsut <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(evah_rsut)) = c("memb","sdate","time")
dim(evah_rsut)

evah_anom = evah_rsdt-(evah_rlut+evah_rsut)

#EVA_H_Carn16
var = 'rsdt'
nc_data <- nc_open(paste0(path_'EC-Earth3_',var,'_EVA_H_Carn16_anom_',reg,'.nc'))
evah_rsdt <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(evah_rsdt)) = c("memb","time")
dim(evah_rsdt)

var = 'rlut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_EVA_H_Carn16_anom_',reg,'.nc'))
evah_rlut <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(evah_rlut)) = c("memb","time")
dim(evah_rlut)

var = 'rsut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_EVA_H_Carn16_anom_',reg,'.nc'))
evah_rsut <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(evah_rsut)) = c("memb","time")
dim(evah_rsut)

hud_anom = hud_rsdt-(hud_rlut+hud_rsut)

dcppA_anom_ens = MeanDims(dcppA_anom,'memb',na.rm = TRUE)
dcppC_anom_ens = MeanDims(dcppC_anom,'memb',na.rm = TRUE)
evah_anom_ens = MeanDims(evah_anom,'memb',na.rm = TRUE)
eva_anom_ens = MeanDims(eva_anom,'memb',na.rm = TRUE)
hud_anom_ens = MeanDims(hud_anom,'memb',na.rm = TRUE)

#Function
signif_boot <- function(data, Rpar, memb){
# Exp with ensemble members
# Rpar - number of repetitions
# memb - number of ensemble members
bootstrap = boot(data, function(x,i) (mean(x[i=c(sample(memb,size=memb,replace=TRUE))],na.rm = TRUE)), R=Rpar)$t
q1 = apply(bootstrap, c(2), function(x) quantile(x,0.025))      
q2 = apply(bootstrap, c(2), function(x) quantile(x,0.975))      
signif <- apply(bootstrap,c(2), function(x) (quantile(x,0.025,na.rm=TRUE)>=0)||(quantile(x,0.975,na.rm=TRUE)<=0))
signif[signif == 0] = NA
return(signif)
}

Rpar=1000
dcppA_boot = apply(dcppA_anom, c(2,3), function(x) (signif_boot(x,Rpar,10)))
dcppC_boot = apply(dcppC_anom, c(2,3), function(x) (signif_boot(x,Rpar,10)))
evah_boot = apply(evah_anom, c(2,3), function(x) (signif_boot(x,Rpar,10)))
eva_boot = apply(eva_anom, c(2,3), function(x) (signif_boot(x,Rpar,10)))
hud_boot = apply(hud_anom, c(2), function(x) (signif_boot(x,Rpar,10)))

#Spread 2 10th and 90th percentile
perc_dcppA = Apply(dcppA_anom, target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output
perc_dcppC = Apply(dcppC_anom, target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output
perc_evah = Apply(evah_anom, target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output
perc_eva = Apply(eva_anom, target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output
perc_hud = Apply(hud_anom, target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output  

options(repr.plot.width = 12, repr.plot.height = 3, repr.plot.res = 200)
par(mfrow=c(1,3))

#PLOT
pcexlab=1.6
pcexmain=1.8
pcexax=1.6

l1 = -4
l2 = 2
le = 48

#Agung
yrs = c(1:108)
plot(yrs, anom_toa_obs_pina[1:108], col="white", type="l", lwd=1, ylim=c(l1,l2), xlim=c(1,le), cex.lab=pcexlab, cex.main=pcexmain, cex.axis=pcexax,
              xlab = "Time", ylab = 'TOA (W/m^2)', main = "a) s1962, Agung", xaxt='n', xaxs="i", lty=2)
lines(yrs,yrs*0, lty=2, col='black',lwd=1)
#lines((c(-5:5)*0)+3,c(-5:5), lty=2, col='black',lwd=0.5)
axis(1, at=seq(1,108,12),labels=c(1963:1971), col.axis="black", cex.axis=pcexax)

polygon(c(yrs,rev(yrs)), c(perc_dcppA[1,1,1:108],rev(perc_dcppA[2,1,1:108])),col =adjustcolor("grey",alpha.f=0.35), border = FALSE)
polygon(c(yrs,rev(yrs)), c(perc_dcppC[1,1,1:108],rev(perc_dcppC[2,1,1:108])),col =adjustcolor("lightsalmon",alpha.f=0.35), border = FALSE)
polygon(c(yrs,rev(yrs)), c(perc_evah[1,1,1:108],rev(perc_evah[2,1,1:108])),col =adjustcolor("pink",alpha.f=0.35), border = FALSE)
polygon(c(yrs,rev(yrs)), c(perc_eva[1,1,1:108],rev(perc_eva[2,1,1:108])),col =adjustcolor("lightblue",alpha.f=0.25), border = FALSE)

lines(yrs, yrs*0, lty=2, col="black", lwd=0.5)
lines(yrs, dcppA_anom_ens[1,1:108], lty=1, col="black", lwd=1, type="l", pch=21)
lines(yrs, dcppC_anom_ens[1,1:108], lty=1, col="orange", lwd=1, type="l", pch=21)
lines(yrs, evah_anom_ens[1,1:108], lty=1, col="red", lwd=1, type="l", pch=21)
lines(yrs, eva_anom_ens[1,1:108], lty=1, col="blue", lwd=1, type="l", pch=21)
lines(yrs, toa_era5[1,1:108], lty="99", col="black", lwd=1, type="l", pch=21)

#El Chichon
yrs = c(1:108)
plot(yrs, anom_toa_obs_pina[1:108], col="white", type="l", lwd=1, ylim=c(l1,l2), xlim=c(1,le), cex.lab=pcexlab, cex.main=pcexmain, cex.axis=pcexax,
              xlab = "Time", ylab = 'TOA (W/m^2)', main = "b) s1981, El Chichon", xaxt='n', xaxs="i", lty=2)
lines(yrs,yrs*0, lty=2, col='black',lwd=1)
#lines((c(-5:5)*0)+3,c(-5:5), lty=2, col='black',lwd=0.5)
axis(1, at=seq(1,108,12),labels=c(1982:1990), col.axis="black", cex.axis=pcexax)

polygon(c(yrs,rev(yrs)), c(perc_dcppA[1,2,1:108],rev(perc_dcppA[2,2,1:108])),col =adjustcolor("grey",alpha.f=0.35), border = FALSE)
polygon(c(yrs,rev(yrs)), c(perc_dcppC[1,2,1:108],rev(perc_dcppC[2,2,1:108])),col =adjustcolor("lightsalmon",alpha.f=0.35), border = FALSE)
polygon(c(yrs,rev(yrs)), c(perc_evah[1,2,1:108],rev(perc_evah[2,2,1:108])),col =adjustcolor("pink",alpha.f=0.35), border = FALSE)
polygon(c(yrs,rev(yrs)), c(perc_eva[1,2,1:108],rev(perc_eva[2,2,1:108])),col =adjustcolor("lightblue",alpha.f=0.25), border = FALSE)

lines(yrs, yrs*0, lty=2, col="black", lwd=0.5)
lines(yrs, dcppA_anom_ens[2,1:108], lty=1, col="black", lwd=1, type="l", pch=21)
lines(yrs, dcppC_anom_ens[2,1:108], lty=1, col="orange", lwd=1, type="l", pch=21)
lines(yrs, evah_anom_ens[2,1:108], lty=1, col="red", lwd=1, type="l", pch=21)
lines(yrs, eva_anom_ens[2,1:108], lty=1, col="blue", lwd=1, type="l", pch=21)
lines(yrs, toa_era5[2,1:108], lty="99", col="black", lwd=1, type="l", pch=21)


#Pinatubo
yrs = c(1:108)
plot(yrs, anom_toa_obs_pina[1:108], col="white", type="l", lwd=1, ylim=c(l1,l2), xlim=c(1,le), cex.lab=pcexlab, cex.main=pcexmain, cex.axis=pcexax,
              xlab = "Time", ylab = 'TOA (W/m^2)', main = "c) s1990, Pinatubo", xaxt='n', xaxs="i", lty=2)
lines(yrs,yrs*0, lty=2, col='black',lwd=1)
#lines((c(-5:5)*0)+6,c(-5:5), lty=2, col='black',lwd=0.5)
axis(1, at=seq(1,108,12),labels=c(1991:1999), col.axis="black", cex.axis=pcexax)

polygon(c(yrs,rev(yrs)), c(perc_hud[1,1:108],rev(perc_hud[2,1:108])),col =adjustcolor("lightgreen",alpha.f=0.35), border = FALSE)
polygon(c(yrs,rev(yrs)), c(perc_dcppA[1,3,1:108],rev(perc_dcppA[2,3,1:108])),col =adjustcolor("grey",alpha.f=0.35), border = FALSE)
polygon(c(yrs,rev(yrs)), c(perc_dcppC[1,3,1:108],rev(perc_dcppC[2,3,1:108])),col =adjustcolor("lightsalmon",alpha.f=0.35), border = FALSE)
polygon(c(yrs,rev(yrs)), c(perc_evah[1,3,1:108],rev(perc_evah[2,3,1:108])),col =adjustcolor("pink",alpha.f=0.35), border = FALSE)
polygon(c(yrs,rev(yrs)), c(perc_eva[1,3,1:108],rev(perc_eva[2,3,1:108])),col =adjustcolor("lightblue",alpha.f=0.25), border = FALSE)

lines(yrs, yrs*0, lty=2, col="black", lwd=0.5)
lines(yrs, dcppA_anom_ens[3,1:108], lty=1, col="black", lwd=1, type="l", pch=21)
lines(yrs, dcppC_anom_ens[3,1:108], lty=1, col="orange", lwd=1, type="l", pch=21)
lines(yrs, evah_anom_ens[3,1:108], lty=1, col="red", lwd=1, type="l", pch=21)
lines(yrs, eva_anom_ens[3,1:108], lty=1, col="blue", lwd=1, type="l", pch=21)
lines(yrs, hud_anom_ens[1:108], lty=1, col="darkgreen", lwd=1, type="l", pch=21)
lines(yrs, anom_toa_obs_pina[1:108], lty="99", col="red", lwd=1, type="l", pch=21)
lines(yrs, toa_era5[3,1:108], lty="99", col="black", lwd=1, type="l", pch=21)

legend(25, -3, legend=c("Deep-C_v5"),
       col=c("red"), lwd=1.5, lty='99', bty="n", 
       y.intersp = 2.5, x.intersp=0.5, text.width=1, cex=1.4, seg.len=0.5)

