################################################################################
## Script for producing figures in Bilbao et al. (2025) The sensitivity of 
## EC-Earth3 decadal predictions to the choice of volcanic forcing dataset: 
## Insights for the next major eruption.
## Script purpose: Compute ERA5 annual latlon anomalies.
## Date: 03/2025
## Author: Roberto Bilbao (roberto.bilbao@bsc.es)
################################################################################

# Load libraries
library(s2dv)
library(multiApply)
library(ncdf4)
library(startR)
library(ClimProjDiags)

# Variable
vari = 'tas'

# Years
yr1 = '1963'
yr2 = '2015'

pathdat = ''

repos <- paste0(pathdat,'$var$_$year$$chunk$.nc')

data <- Start(dat = repos,
              var = vari,
              year = paste(seq(yr1,yr2)),
              time = 'all',
              latitude = 'all',
              longitude = 'all',
              longitude_reorder = CircularSort(0, 360),
              synonims = list(longitude = c('lon', 'longitude'), latitude = c('lat', 'latitude')),
              chunk = 'all',
              chunk_depends = 'year',
              time_across = 'chunk',
              merge_across_dims = TRUE,
              return_vars = list(time=NULL, latitude='dat', longitude='dat'),
              retrieve = T)
lat_cmip6 = as.vector(attr(data, 'Variables')$dat1$latitude)
lon_cmip6 = as.vector(attr(data, 'Variables')$dat1$longitude)

cyr1 = 1971
cyr2 = 2015

n1 = cyr1-as.numeric(yr1)+1
n2 = cyr2-as.numeric(yr1)+1

clim = MeanDims(drop(data)[n1:n2,,,],c('year'))

agung = drop(data)[(1963-as.numeric(yr1)+1):(1963-as.numeric(yr1)+10),,,]
chichon = drop(data)[(1982-as.numeric(yr1)+1):(1982-as.numeric(yr1)+10),,,]
pina = drop(data)[(1991-as.numeric(yr1)+1):(1991-as.numeric(yr1)+10),,,]

era5_agung_anom = MeanDims(agung-InsertDim(clim,1,10),c('time'))
era5_elchichon_anom = MeanDims(chichon-InsertDim(clim,1,10),c('time'))
era5_pinatubo_anom = MeanDims(pina-InsertDim(clim,1,10),c('time'))

era5_anom = InsertDim(era5_agung_anom,1,3,'sdate')
era5_anom[2,,,] = era5_elchichon_anom
era5_anom[3,,,] = era5_pinatubo_anom

# Save ncdf
dat = Reorder(era5_anom,c('longitude','latitude','sdate','year'))
sdate = c(1962,1981,1990)
time = c(1:10)
latitude = lat_cmip6
longitude = lon_cmip6

# Create netcdf file:
filename = paste0('ERA5_',vari,'_anom_latlon.nc', sep='')
flcomment =  paste0('ERA5 ',vari,' anomalies') 
# Create netcdf file including yearly anomalies:
units= 'degrees'
fillvalue=-1
dim1 = ncdim_def( "latitude","degrees_north", as.vector(lat_cmip6))
dim2 = ncdim_def( "longitude","degrees_east", as.vector(lon_cmip6))
dim3 = ncdim_def( "sdate","year", sdate)
dim4 = ncdim_def( "time","year", time)
var1 = ncvar_def( vari,units,list(dim2,dim1,dim3,dim4),fillvalue,flcomment)
nc.file = nc_create(filename,list(var1))
ncvar_put(nc.file,var1,dat)
nc_close(nc.file)