################################################################################
## Script for producing figures in Bilbao et al. (2025) The sensitivity of 
## EC-Earth3 decadal predictions to the choice of volcanic forcing dataset: 
## Insights for the next major eruption.
## Script purpose: Compute ERA5 reional mean anomalies.
## Date: 03/2025
## Author: Roberto Bilbao (roberto.bilbao@bsc.es)
################################################################################

# Load libraries
library(s2dv)
library(ncdf4)
library(startR)
library(ClimProjDiags)

# Variable (ta100, tsr)
var = 'tas'

# Path to data
#pathdat = ''
pathdat = paste0('/esarchive/recon/ecmwf/era5/monthly_mean/',var,'_f1h-r1440x721cds/')

# Years
yr1 = 1961
yr2 = 2015

# Clim years
yr1_clim = 1985
yr2_clim = 2015

# Region
lons.min <- c(0)
lons.max <- c(360)
lats.min <- c(-90)
lats.max <- c(90)

# Region name
regname = 'globalmean'

# Load ERA5 monthly data by year
ti = paste0(rep(c(yr1:yr2),each=12),c('01','02','03','04','05','06','07','08','09','10','11','12'))
reg = c(1:length(ti))*0
for (t in c(1:length(ti))){
print(ti[t])    
nc_data <- nc_open(paste0(pathdat,var,'_',ti[t],'.nc'))
data <- Reorder(ncvar_get(nc_data, var),c(2,1))
lat = ncvar_get(nc_data, 'lat')
lon = ncvar_get(nc_data, 'lon')
nc_close(nc_data)
names(dim(data)) = c("lat","lon")
dim(data)

reg[t] <- WeightedMean(data=data, lon=as.vector(lon), lat=as.vector(lat), region=c(lons.min,lons.max,lats.min,lats.max), londim=2, latdim=1)    
}

# Compute clim
anom = reg
dim(anom) = c(12,(yr2-yr1+1))
names(dim(anom)) = c("mon","yr")
clim_era5 = MeanDims(anom[,(yr1-yr1_clim+1):(yr1-yr2_clim+1)],'yr')

#Anom
agung_anom = anom[,(1963-yr1+1):(1963-yr1+10)]-InsertDim(clim_era5,2,10,'yr')
dim(agung_anom) = 120
chichon_anom = anom[,(1982-yr1+1):(1982-yr1+10)]-InsertDim(clim_era5,2,10,'yr')
dim(chichon_anom) = 120
pina_anom = anom[,(1991-yr1+1):(1991-yr1+10)]-InsertDim(clim_era5,2,10,'yr')
dim(pina_anom) = 120

era5_anom = InsertDim(agung_anom,1,3,'sdate')
era5_anom[2,] = chichon_anom
era5_anom[3,] = pina_anom

# Save ncdf
sdate = c(1962,1981,1990)
time = c(1:120)

# Create netcdf file:
filename = paste0('ERA5_',var,'_anom_',regname,'_test.nc')
flcomment =  paste0('ERA, ',var,' ',regname) 
# Create netcdf file including yearly anomalies:
units= 'degrees'
fillvalue=-1
dim1 = ncdim_def( "sdate","year", sdate)
dim2 = ncdim_def( "time","year", time)
var1 = ncvar_def( var, units,list(dim1,dim2),fillvalue,flcomment)
nc.file = nc_create(filename,list(var1))
ncvar_put(nc.file,var1,era5_anom)
nc_close(nc.file)