################################################################################
## Script for producing figures in Bilbao et al. (2025) The sensitivity of 
## EC-Earth3 decadal predictions to the choice of volcanic forcing dataset: 
## Insights for the next major eruption.
## Script purpose: Compute latlon, regional mean and zonal mean files for the 
## prediction experiments for 2D variables.
## Date: 03/2025
## Author: Roberto Bilbao (roberto.bilbao@bsc.es)
################################################################################

# Load libraries
library(s2dv)
library(ncdf4)
library(startR)
library(s2dv)
library(ClimProjDiags)

# Experiment (dcppA_hindcast, dcppC_hindcast, EVA, EVA_H, EVA_Carn16)
exp = 'dcppA_hindcast'

# Variable (tas, rsdt, rsut, rlut)
vari = 'tas'

# Table
mod = 'Amon'

# Grid
grid = 'gr'

# Path to data
pathdat = ''

# Members
membs = c('r1i1p1f1','r2i1p1f1','r3i1p1f1','r4i1p1f1','r5i1p1f1','r6i1p1f1','r7i1p1f1','r8i1p1f1','r9i1p1f1','r10i1p1f1')
nmemb=10

# Startdates
sdates = c(1962,1981,1990)

# Lats and Lons
lons.min <- 0
lons.max <- 359
lats.min <- -90
lats.max <- 90

# Load Data
repos <- paste0(pathdat,'$var$_',mod,'_EC-Earth3_dcpp_',exp,'_s$sdate$*-$memb$_',grid,'_$chunk$.nc',sep='')
data_volc <- Start(dat = repos,
             var = vari,
             memb = membs,
             sdate = sdates,
             time = c(3:122),
             latitude = values(list(lats.min, lats.max)),
             longitude = values(list(lons.min, lons.max)),
             synonims = list(longitude = c('lon', 'longitude'), latitude = c('lat', 'latitude')),
             chunk = 'all',
             chunk_depends = 'sdate',
             time_across = 'chunk',
             merge_across_dims = TRUE,
             return_vars = list(time=NULL, latitude='dat', longitude='dat'),
             transform = CDORemapper,
             transform_extra_cells = 2,
             transform_params = list(grid = 'r360x180', method = 'con', crop=c(lons.min, lons.max, lats.min, lats.max)),
             transform_vars = c('latitude', 'longitude'),
             retrieve = T)

lat_cmip6 = as.vector(attr(data_volc, 'Variables')$dat1$latitude)
lon_cmip6 = as.vector(attr(data_volc, 'Variables')$dat1$longitude)
data = drop(data_volc)

savenc = TRUE
if (savenc == TRUE){

#Reorder
data2 = Reorder(data, c('longitude','latitude','memb','sdate','time'))

# Save netcdf file:
ensem = c(1:nmemb)
time = c(1:120)
latitude = lat_cmip6
longitude = lon_cmip6
filename = paste0('EC-Earth3',vari,'_',exp,'_latlon_1deg_monthly.nc', sep='')
flcomment =  paste0(exp,' ',vari,', latlon, monthly', sep='')
units= 'degrees'
fillvalue=-1
dim1 = ncdim_def( "member","memb", ensem)
dim2 = ncdim_def( "sdate","yr", sdate)
dim3 = ncdim_def( "time","month", time)
dim4 = ncdim_def( "latitude","degrees_north", as.vector(lat_cmip6))
dim5 = ncdim_def( "longitude","degrees_east", as.vector(lon_cmip6))
var1 = ncvar_def( vari,units,list(dim5,dim4,dim1,dim2,dim3),fillvalue,flcomment)
nc.file = nc_create(filename,list(var1))
ncvar_put(nc.file,var1,data2)
nc_close(nc.file)
}

regmeans = TRUE
if (regmeans == TRUE){

# Regional Means
index = c('globalmean','nino34','tropics','AMV1','AMV2','SPG','LabSea','TropPac','TropPacE','TropPacW')
lons.min <- c(0,190,0,0,280,300,302,150,215,150)
lons.max <- c(360,240,360,360,360,350,317,280,280,215)
lats.min <- c(-90,-5,-30,-60,0,50,52,-5,-5,-5)
lats.max <- c(90,5,30,60,60,65,65,5,5,5)

for(i in c(1:10)){

data_volcm <- WeightedMean(data=data, lon=lon_cmip6, lat=lat_cmip6, region=c(lons.min[i],lons.max[i],lats.min[i],lats.max[i]), londim=5, latdim=4)

ensem = c(1:nmemb)
time = c(1:120)

# Create netcdf file:
filename = paste0('EC-Earth3_',vari,'_',exp,'_',index[i],'.nc', sep='')
flcomment =  paste0(exp,' ',vari,', latlon, monthly', sep='')
units= 'degrees'
fillvalue=-1
dim2 = ncdim_def( "member","memb", ensem)
dim3 = ncdim_def( "sdate","yr", sdate)
dim4 = ncdim_def( "time","month", time)
var1 = ncvar_def( vari,units,list(dim2,dim3,dim4),fillvalue,flcomment)
nc.file = nc_create(filename,list(var1))
ncvar_put(nc.file,var1,data_volcm)
nc_close(nc.file)
}
}

zonmean = TRUE
if (zonmean == TRUE){

# Zonal mean
dataz = MeanDims(data,c('longitude'))

# Save netcdf file:
ensem = c(1:nmemb)
time = c(1:120)
latitude = lat_cmip6
longitude = lon_cmip6
filename = paste0('EC-Earth3_',vari,'_',exp,'_zonmean_monthly.nc', sep='')
flcomment =  paste0(exp,' ',vari,', latlon, monthly', sep='')
units= 'degrees'
fillvalue=-1
dim1 = ncdim_def( "member","memb", ensem)
dim2 = ncdim_def( "sdate","yr", sdate)
dim3 = ncdim_def( "time","month", time)
dim4 = ncdim_def( "latitude","degrees_north", as.vector(lat_cmip6))
var1 = ncvar_def( vari,units,list(dim1,dim2,dim3,dim4),fillvalue,flcomment)
nc.file = nc_create(filename,list(var1))
ncvar_put(nc.file,var1,dataz)
nc_close(nc.file)

}